# coding: utf-8

# flake8: noqa

"""
    Onshape REST API

    The Onshape REST API consumed by all clients.  # noqa: E501

    The version of the OpenAPI document: 1.113
    Contact: api-support@onshape.zendesk.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

__version__ = "1.0.0"

# import apis into sdk package
from onshape_client.oas.api.accounts_api import AccountsApi
from onshape_client.oas.api.app_elements_api import AppElementsApi
from onshape_client.oas.api.applications_api import ApplicationsApi
from onshape_client.oas.api.assemblies_api import AssembliesApi
from onshape_client.oas.api.billing_api import BillingApi
from onshape_client.oas.api.blob_elements_api import BlobElementsApi
from onshape_client.oas.api.companies_api import CompaniesApi
from onshape_client.oas.api.documents_api import DocumentsApi
from onshape_client.oas.api.drawings_api import DrawingsApi
from onshape_client.oas.api.elements_api import ElementsApi
from onshape_client.oas.api.feature_studios_api import FeatureStudiosApi
from onshape_client.oas.api.folders_api import FoldersApi
from onshape_client.oas.api.metadata_api import MetadataApi
from onshape_client.oas.api.open_api_api import OpenAPIApi
from onshape_client.oas.api.part_studios_api import PartStudiosApi
from onshape_client.oas.api.parts_api import PartsApi
from onshape_client.oas.api.release_management_api import ReleaseManagementApi
from onshape_client.oas.api.revisions_api import RevisionsApi
from onshape_client.oas.api.teams_api import TeamsApi
from onshape_client.oas.api.thumbnails_api import ThumbnailsApi
from onshape_client.oas.api.translations_api import TranslationsApi
from onshape_client.oas.api.users_api import UsersApi
from onshape_client.oas.api.versions_api import VersionsApi
from onshape_client.oas.api.webhooks_api import WebhooksApi
from onshape_client.oas.api.workflow_api import WorkflowApi
from onshape_client.oas.api.default_api import DefaultApi

# import ApiClient
from onshape_client.oas.api_client import ApiClient

# import Configuration
from onshape_client.oas.configuration import Configuration

# import exceptions
from onshape_client.oas.exceptions import OpenApiException
from onshape_client.oas.exceptions import ApiTypeError
from onshape_client.oas.exceptions import ApiValueError
from onshape_client.oas.exceptions import ApiKeyError
from onshape_client.oas.exceptions import ApiException

# import models into sdk package
from onshape_client.oas.models.address import Address
from onshape_client.oas.models.body_part import BodyPart
from onshape_client.oas.models.body_part_media_type import BodyPartMediaType
from onshape_client.oas.models.bt_acl_entry_info import BTAclEntryInfo
from onshape_client.oas.models.bt_acl_info import BTAclInfo
from onshape_client.oas.models.bt_active_sheet_metal_filter2944 import (
    BTActiveSheetMetalFilter2944,
)
from onshape_client.oas.models.bt_active_sheet_metal_filter2944_all_of import (
    BTActiveSheetMetalFilter2944AllOf,
)
from onshape_client.oas.models.bt_active_workflow_info import BTActiveWorkflowInfo
from onshape_client.oas.models.bt_address_info import BTAddressInfo
from onshape_client.oas.models.bt_allow_edge_point_filter2371 import (
    BTAllowEdgePointFilter2371,
)
from onshape_client.oas.models.bt_allow_edge_point_filter2371_all_of import (
    BTAllowEdgePointFilter2371AllOf,
)
from onshape_client.oas.models.bt_allow_flattened_geometry_filter2140 import (
    BTAllowFlattenedGeometryFilter2140,
)
from onshape_client.oas.models.bt_allow_flattened_geometry_filter2140_all_of import (
    BTAllowFlattenedGeometryFilter2140AllOf,
)
from onshape_client.oas.models.bt_allow_mesh_geometry_filter1026 import (
    BTAllowMeshGeometryFilter1026,
)
from onshape_client.oas.models.bt_allow_mesh_geometry_filter1026_all_of import (
    BTAllowMeshGeometryFilter1026AllOf,
)
from onshape_client.oas.models.bt_allowed_mate_type_filter1511 import (
    BTAllowedMateTypeFilter1511,
)
from onshape_client.oas.models.bt_allowed_mate_type_filter1511_all_of import (
    BTAllowedMateTypeFilter1511AllOf,
)
from onshape_client.oas.models.bt_and_filter110 import BTAndFilter110
from onshape_client.oas.models.bt_and_filter110_all_of import BTAndFilter110AllOf
from onshape_client.oas.models.bt_app_associative_data_info_array import (
    BTAppAssociativeDataInfoArray,
)
from onshape_client.oas.models.bt_app_element_basic_info import BTAppElementBasicInfo
from onshape_client.oas.models.bt_app_element_change_params import (
    BTAppElementChangeParams,
)
from onshape_client.oas.models.bt_app_element_commit_transaction_params import (
    BTAppElementCommitTransactionParams,
)
from onshape_client.oas.models.bt_app_element_content_delta_info import (
    BTAppElementContentDeltaInfo,
)
from onshape_client.oas.models.bt_app_element_content_entry_info import (
    BTAppElementContentEntryInfo,
)
from onshape_client.oas.models.bt_app_element_content_info import (
    BTAppElementContentInfo,
)
from onshape_client.oas.models.bt_app_element_history_entry_info import (
    BTAppElementHistoryEntryInfo,
)
from onshape_client.oas.models.bt_app_element_history_info import (
    BTAppElementHistoryInfo,
)
from onshape_client.oas.models.bt_app_element_modify_info import BTAppElementModifyInfo
from onshape_client.oas.models.bt_app_element_params import BTAppElementParams
from onshape_client.oas.models.bt_app_element_reference_info import (
    BTAppElementReferenceInfo,
)
from onshape_client.oas.models.bt_app_element_reference_params import (
    BTAppElementReferenceParams,
)
from onshape_client.oas.models.bt_app_element_reference_resolve_info import (
    BTAppElementReferenceResolveInfo,
)
from onshape_client.oas.models.bt_app_element_references_resolve_info import (
    BTAppElementReferencesResolveInfo,
)
from onshape_client.oas.models.bt_app_element_start_transaction_params import (
    BTAppElementStartTransactionParams,
)
from onshape_client.oas.models.bt_app_element_update_params import (
    BTAppElementUpdateParams,
)
from onshape_client.oas.models.bt_application_element_thumbnail_params import (
    BTApplicationElementThumbnailParams,
)
from onshape_client.oas.models.bt_application_element_thumbnail_params_array import (
    BTApplicationElementThumbnailParamsArray,
)
from onshape_client.oas.models.bt_assembly_definition_info import (
    BTAssemblyDefinitionInfo,
)
from onshape_client.oas.models.bt_assembly_feature_data_info import (
    BTAssemblyFeatureDataInfo,
)
from onshape_client.oas.models.bt_assembly_feature_info import BTAssemblyFeatureInfo
from onshape_client.oas.models.bt_assembly_feature_list_response1174 import (
    BTAssemblyFeatureListResponse1174,
)
from onshape_client.oas.models.bt_assembly_feature_list_response1174_all_of import (
    BTAssemblyFeatureListResponse1174AllOf,
)
from onshape_client.oas.models.bt_assembly_insert_transformed_instances_response import (
    BTAssemblyInsertTransformedInstancesResponse,
)
from onshape_client.oas.models.bt_assembly_instance_definition_params import (
    BTAssemblyInstanceDefinitionParams,
)
from onshape_client.oas.models.bt_assembly_instance_info import BTAssemblyInstanceInfo
from onshape_client.oas.models.bt_assembly_mated_entity import BTAssemblyMatedEntity
from onshape_client.oas.models.bt_assembly_occurrence_info import (
    BTAssemblyOccurrenceInfo,
)
from onshape_client.oas.models.bt_assembly_parts_info import BTAssemblyPartsInfo
from onshape_client.oas.models.bt_assembly_ps_feature_info import (
    BTAssemblyPSFeatureInfo,
)
from onshape_client.oas.models.bt_assembly_transform_definition_params import (
    BTAssemblyTransformDefinitionParams,
)
from onshape_client.oas.models.bt_assembly_transformed_instances_definition_params import (
    BTAssemblyTransformedInstancesDefinitionParams,
)
from onshape_client.oas.models.bt_associative_data_info import BTAssociativeDataInfo
from onshape_client.oas.models.bt_base_info import BTBaseInfo
from onshape_client.oas.models.bt_base_sm_joint_table_row_metadata2232 import (
    BTBaseSMJointTableRowMetadata2232,
)
from onshape_client.oas.models.bt_base_sm_joint_table_row_metadata2232_all_of import (
    BTBaseSMJointTableRowMetadata2232AllOf,
)
from onshape_client.oas.models.bt_bill_of_materials_table1073 import (
    BTBillOfMaterialsTable1073,
)
from onshape_client.oas.models.bt_bill_of_materials_table1073_all_of import (
    BTBillOfMaterialsTable1073AllOf,
)
from onshape_client.oas.models.bt_bill_of_materials_table_row1425 import (
    BTBillOfMaterialsTableRow1425,
)
from onshape_client.oas.models.bt_bill_of_materials_table_row1425_all_of import (
    BTBillOfMaterialsTableRow1425AllOf,
)
from onshape_client.oas.models.bt_bill_of_materials_table_row_metadata1300 import (
    BTBillOfMaterialsTableRowMetadata1300,
)
from onshape_client.oas.models.bt_bill_of_materials_table_row_metadata1300_all_of import (
    BTBillOfMaterialsTableRowMetadata1300AllOf,
)
from onshape_client.oas.models.bt_bill_of_materials_unique_item_id2029 import (
    BTBillOfMaterialsUniqueItemId2029,
)
from onshape_client.oas.models.bt_billing_plan_info import BTBillingPlanInfo
from onshape_client.oas.models.bt_body_type_filter112 import BTBodyTypeFilter112
from onshape_client.oas.models.bt_body_type_filter112_all_of import (
    BTBodyTypeFilter112AllOf,
)
from onshape_client.oas.models.bt_bounding_box1052 import BTBoundingBox1052
from onshape_client.oas.models.bt_bounding_box_info import BTBoundingBoxInfo
from onshape_client.oas.models.bt_cache_data_path191 import BTCacheDataPath191
from onshape_client.oas.models.bt_card_info import BTCardInfo
from onshape_client.oas.models.bt_circle_description1145 import BTCircleDescription1145
from onshape_client.oas.models.bt_circle_description1145_all_of import (
    BTCircleDescription1145AllOf,
)
from onshape_client.oas.models.bt_closed_curve_filter1206 import BTClosedCurveFilter1206
from onshape_client.oas.models.bt_closed_curve_filter1206_all_of import (
    BTClosedCurveFilter1206AllOf,
)
from onshape_client.oas.models.bt_cloud_storage_account_info import (
    BTCloudStorageAccountInfo,
)
from onshape_client.oas.models.bt_cloud_storage_account_info_all_of import (
    BTCloudStorageAccountInfoAllOf,
)
from onshape_client.oas.models.bt_cloud_storage_object_info import (
    BTCloudStorageObjectInfo,
)
from onshape_client.oas.models.bt_color_info import BTColorInfo
from onshape_client.oas.models.bt_color_params import BTColorParams
from onshape_client.oas.models.bt_comment_attachment_info import BTCommentAttachmentInfo
from onshape_client.oas.models.bt_comment_info import BTCommentInfo
from onshape_client.oas.models.bt_common_unit_info import BTCommonUnitInfo
from onshape_client.oas.models.bt_common_units_info import BTCommonUnitsInfo
from onshape_client.oas.models.bt_company_info import BTCompanyInfo
from onshape_client.oas.models.bt_company_summary_info import BTCompanySummaryInfo
from onshape_client.oas.models.bt_computed_configuration_input_spec2525 import (
    BTComputedConfigurationInputSpec2525,
)
from onshape_client.oas.models.bt_cone_description860 import BTConeDescription860
from onshape_client.oas.models.bt_cone_description860_all_of import (
    BTConeDescription860AllOf,
)
from onshape_client.oas.models.bt_configuration_info import BTConfigurationInfo
from onshape_client.oas.models.bt_configuration_params import BTConfigurationParams
from onshape_client.oas.models.bt_configuration_response2019 import (
    BTConfigurationResponse2019,
)
from onshape_client.oas.models.bt_configuration_update_call2933 import (
    BTConfigurationUpdateCall2933,
)
from onshape_client.oas.models.bt_configuration_update_call2933_all_of import (
    BTConfigurationUpdateCall2933AllOf,
)
from onshape_client.oas.models.bt_configured_dimension_column_info2168 import (
    BTConfiguredDimensionColumnInfo2168,
)
from onshape_client.oas.models.bt_configured_dimension_column_info2168_all_of import (
    BTConfiguredDimensionColumnInfo2168AllOf,
)
from onshape_client.oas.models.bt_configured_feature_column_info1014 import (
    BTConfiguredFeatureColumnInfo1014,
)
from onshape_client.oas.models.bt_configured_feature_column_info1014_all_of import (
    BTConfiguredFeatureColumnInfo1014AllOf,
)
from onshape_client.oas.models.bt_configured_parameter_column_info2900 import (
    BTConfiguredParameterColumnInfo2900,
)
from onshape_client.oas.models.bt_configured_parameter_column_info2900_all_of import (
    BTConfiguredParameterColumnInfo2900AllOf,
)
from onshape_client.oas.models.bt_configured_part_properties_table2740 import (
    BTConfiguredPartPropertiesTable2740,
)
from onshape_client.oas.models.bt_configured_part_properties_table2740_all_of import (
    BTConfiguredPartPropertiesTable2740AllOf,
)
from onshape_client.oas.models.bt_configured_suppression_column_info2498 import (
    BTConfiguredSuppressionColumnInfo2498,
)
from onshape_client.oas.models.bt_configured_values_column_info1025 import (
    BTConfiguredValuesColumnInfo1025,
)
from onshape_client.oas.models.bt_configured_values_column_info1025_all_of import (
    BTConfiguredValuesColumnInfo1025AllOf,
)
from onshape_client.oas.models.bt_construction_object_filter113 import (
    BTConstructionObjectFilter113,
)
from onshape_client.oas.models.bt_construction_object_filter113_all_of import (
    BTConstructionObjectFilter113AllOf,
)
from onshape_client.oas.models.bt_copy_document_info import BTCopyDocumentInfo
from onshape_client.oas.models.bt_copy_document_params import BTCopyDocumentParams
from onshape_client.oas.models.bt_copy_element_params import BTCopyElementParams
from onshape_client.oas.models.bt_curve_description1583 import BTCurveDescription1583
from onshape_client.oas.models.bt_curve_geometry114 import BTCurveGeometry114
from onshape_client.oas.models.bt_curve_geometry_circle115 import (
    BTCurveGeometryCircle115,
)
from onshape_client.oas.models.bt_curve_geometry_circle115_all_of import (
    BTCurveGeometryCircle115AllOf,
)
from onshape_client.oas.models.bt_curve_geometry_conic2284 import (
    BTCurveGeometryConic2284,
)
from onshape_client.oas.models.bt_curve_geometry_conic2284_all_of import (
    BTCurveGeometryConic2284AllOf,
)
from onshape_client.oas.models.bt_curve_geometry_ellipse1189 import (
    BTCurveGeometryEllipse1189,
)
from onshape_client.oas.models.bt_curve_geometry_ellipse1189_all_of import (
    BTCurveGeometryEllipse1189AllOf,
)
from onshape_client.oas.models.bt_curve_geometry_interpolated_spline116 import (
    BTCurveGeometryInterpolatedSpline116,
)
from onshape_client.oas.models.bt_curve_geometry_interpolated_spline116_all_of import (
    BTCurveGeometryInterpolatedSpline116AllOf,
)
from onshape_client.oas.models.bt_curve_geometry_line117 import BTCurveGeometryLine117
from onshape_client.oas.models.bt_curve_geometry_line117_all_of import (
    BTCurveGeometryLine117AllOf,
)
from onshape_client.oas.models.bt_curve_geometry_spline118 import (
    BTCurveGeometrySpline118,
)
from onshape_client.oas.models.bt_curve_geometry_spline118_all_of import (
    BTCurveGeometrySpline118AllOf,
)
from onshape_client.oas.models.bt_custom_property_definition_info import (
    BTCustomPropertyDefinitionInfo,
)
from onshape_client.oas.models.bt_custom_property_definition_params import (
    BTCustomPropertyDefinitionParams,
)
from onshape_client.oas.models.bt_cylinder_description686 import (
    BTCylinderDescription686,
)
from onshape_client.oas.models.bt_cylinder_description686_all_of import (
    BTCylinderDescription686AllOf,
)
from onshape_client.oas.models.bt_default_unit_info import BTDefaultUnitInfo
from onshape_client.oas.models.bt_default_units_info import BTDefaultUnitsInfo
from onshape_client.oas.models.bt_diff_info import BTDiffInfo
from onshape_client.oas.models.bt_discount_info import BTDiscountInfo
from onshape_client.oas.models.bt_document_element_info import BTDocumentElementInfo
from onshape_client.oas.models.bt_document_element_processing_info import (
    BTDocumentElementProcessingInfo,
)
from onshape_client.oas.models.bt_document_info import BTDocumentInfo
from onshape_client.oas.models.bt_document_label_info import BTDocumentLabelInfo
from onshape_client.oas.models.bt_document_merge_info import BTDocumentMergeInfo
from onshape_client.oas.models.bt_document_params import BTDocumentParams
from onshape_client.oas.models.bt_document_processing_info import (
    BTDocumentProcessingInfo,
)
from onshape_client.oas.models.bt_document_processing_info_all_of import (
    BTDocumentProcessingInfoAllOf,
)
from onshape_client.oas.models.bt_document_search_hit_info import (
    BTDocumentSearchHitInfo,
)
from onshape_client.oas.models.bt_document_search_params import BTDocumentSearchParams
from onshape_client.oas.models.bt_document_summary_info import BTDocumentSummaryInfo
from onshape_client.oas.models.bt_document_summary_info_all_of import (
    BTDocumentSummaryInfoAllOf,
)
from onshape_client.oas.models.bt_document_summary_search_info import (
    BTDocumentSummarySearchInfo,
)
from onshape_client.oas.models.bt_document_summary_search_info_all_of import (
    BTDocumentSummarySearchInfoAllOf,
)
from onshape_client.oas.models.bt_document_version_element_ids1897 import (
    BTDocumentVersionElementIds1897,
)
from onshape_client.oas.models.bt_document_with_version_and_element_id import (
    BTDocumentWithVersionAndElementId,
)
from onshape_client.oas.models.bt_document_with_version_id import (
    BTDocumentWithVersionId,
)
from onshape_client.oas.models.bt_drawing_params import BTDrawingParams
from onshape_client.oas.models.bt_edge_topology_filter122 import BTEdgeTopologyFilter122
from onshape_client.oas.models.bt_edge_topology_filter122_all_of import (
    BTEdgeTopologyFilter122AllOf,
)
from onshape_client.oas.models.bt_editing_logic2350 import BTEditingLogic2350
from onshape_client.oas.models.bt_element_location_params import BTElementLocationParams
from onshape_client.oas.models.bt_element_reference725 import BTElementReference725
from onshape_client.oas.models.bt_ellipse_description866 import BTEllipseDescription866
from onshape_client.oas.models.bt_ellipse_description866_all_of import (
    BTEllipseDescription866AllOf,
)
from onshape_client.oas.models.bt_encoded_configuration_info import (
    BTEncodedConfigurationInfo,
)
from onshape_client.oas.models.bt_entity_type_filter124 import BTEntityTypeFilter124
from onshape_client.oas.models.bt_entity_type_filter124_all_of import (
    BTEntityTypeFilter124AllOf,
)
from onshape_client.oas.models.bt_explosion2754 import BTExplosion2754
from onshape_client.oas.models.bt_explosion2754_all_of import BTExplosion2754AllOf
from onshape_client.oas.models.bt_explosion_step_feature3008 import (
    BTExplosionStepFeature3008,
)
from onshape_client.oas.models.bt_export_model_arc_edge_geometry1257 import (
    BTExportModelArcEdgeGeometry1257,
)
from onshape_client.oas.models.bt_export_model_arc_edge_geometry1257_all_of import (
    BTExportModelArcEdgeGeometry1257AllOf,
)
from onshape_client.oas.models.bt_export_model_bodies_response734 import (
    BTExportModelBodiesResponse734,
)
from onshape_client.oas.models.bt_export_model_body1272 import BTExportModelBody1272
from onshape_client.oas.models.bt_export_model_coedge1342 import BTExportModelCoedge1342
from onshape_client.oas.models.bt_export_model_edge1782 import BTExportModelEdge1782
from onshape_client.oas.models.bt_export_model_edge_geometry1125 import (
    BTExportModelEdgeGeometry1125,
)
from onshape_client.oas.models.bt_export_model_face1363 import BTExportModelFace1363
from onshape_client.oas.models.bt_export_model_loop1182 import BTExportModelLoop1182
from onshape_client.oas.models.bt_export_model_params import BTExportModelParams
from onshape_client.oas.models.bt_export_model_vertex858 import BTExportModelVertex858
from onshape_client.oas.models.bt_export_tessellated_body3398 import (
    BTExportTessellatedBody3398,
)
from onshape_client.oas.models.bt_export_tessellated_edges_body890 import (
    BTExportTessellatedEdgesBody890,
)
from onshape_client.oas.models.bt_export_tessellated_edges_body890_all_of import (
    BTExportTessellatedEdgesBody890AllOf,
)
from onshape_client.oas.models.bt_export_tessellated_edges_edge1364 import (
    BTExportTessellatedEdgesEdge1364,
)
from onshape_client.oas.models.bt_export_tessellated_edges_response327 import (
    BTExportTessellatedEdgesResponse327,
)
from onshape_client.oas.models.bt_export_tessellated_faces_body1321 import (
    BTExportTessellatedFacesBody1321,
)
from onshape_client.oas.models.bt_export_tessellated_faces_body1321_all_of import (
    BTExportTessellatedFacesBody1321AllOf,
)
from onshape_client.oas.models.bt_export_tessellated_faces_face1192 import (
    BTExportTessellatedFacesFace1192,
)
from onshape_client.oas.models.bt_export_tessellated_faces_facet1417 import (
    BTExportTessellatedFacesFacet1417,
)
from onshape_client.oas.models.bt_export_tessellated_faces_response898 import (
    BTExportTessellatedFacesResponse898,
)
from onshape_client.oas.models.bt_external_element_reference_info import (
    BTExternalElementReferenceInfo,
)
from onshape_client.oas.models.bt_external_reference1936 import BTExternalReference1936
from onshape_client.oas.models.bt_external_reference1936_all_of import (
    BTExternalReference1936AllOf,
)
from onshape_client.oas.models.bt_feature_api_base1430 import BTFeatureApiBase1430
from onshape_client.oas.models.bt_feature_definition_call1406 import (
    BTFeatureDefinitionCall1406,
)
from onshape_client.oas.models.bt_feature_definition_call1406_all_of import (
    BTFeatureDefinitionCall1406AllOf,
)
from onshape_client.oas.models.bt_feature_definition_response1617 import (
    BTFeatureDefinitionResponse1617,
)
from onshape_client.oas.models.bt_feature_definition_response1617_all_of import (
    BTFeatureDefinitionResponse1617AllOf,
)
from onshape_client.oas.models.bt_feature_filter127 import BTFeatureFilter127
from onshape_client.oas.models.bt_feature_filter127_all_of import (
    BTFeatureFilter127AllOf,
)
from onshape_client.oas.models.bt_feature_list_response2457 import (
    BTFeatureListResponse2457,
)
from onshape_client.oas.models.bt_feature_list_response2457_all_of import (
    BTFeatureListResponse2457AllOf,
)
from onshape_client.oas.models.bt_feature_script_eval_call2377 import (
    BTFeatureScriptEvalCall2377,
)
from onshape_client.oas.models.bt_feature_script_eval_response1859 import (
    BTFeatureScriptEvalResponse1859,
)
from onshape_client.oas.models.bt_feature_spec129 import BTFeatureSpec129
from onshape_client.oas.models.bt_feature_specs_response664 import (
    BTFeatureSpecsResponse664,
)
from onshape_client.oas.models.bt_feature_state1688 import BTFeatureState1688
from onshape_client.oas.models.bt_feature_studio_contents2239 import (
    BTFeatureStudioContents2239,
)
from onshape_client.oas.models.bt_feature_studio_contents2239_all_of import (
    BTFeatureStudioContents2239AllOf,
)
from onshape_client.oas.models.bt_feature_type_filter962 import BTFeatureTypeFilter962
from onshape_client.oas.models.bt_feature_type_filter962_all_of import (
    BTFeatureTypeFilter962AllOf,
)
from onshape_client.oas.models.bt_flat_sheet_metal_filter3018 import (
    BTFlatSheetMetalFilter3018,
)
from onshape_client.oas.models.bt_flat_sheet_metal_filter3018_all_of import (
    BTFlatSheetMetalFilter3018AllOf,
)
from onshape_client.oas.models.bt_folder_info import BTFolderInfo
from onshape_client.oas.models.bt_folder_info_all_of import BTFolderInfoAllOf
from onshape_client.oas.models.bt_foreign_data_response1070 import (
    BTForeignDataResponse1070,
)
from onshape_client.oas.models.bt_full_element_id756 import BTFullElementId756
from onshape_client.oas.models.bt_full_element_id_and_part_id643 import (
    BTFullElementIdAndPartId643,
)
from onshape_client.oas.models.bt_full_element_id_and_part_id643_all_of import (
    BTFullElementIdAndPartId643AllOf,
)
from onshape_client.oas.models.bt_full_element_id_with_document1729 import (
    BTFullElementIdWithDocument1729,
)
from onshape_client.oas.models.bt_full_element_id_with_document1729_all_of import (
    BTFullElementIdWithDocument1729AllOf,
)
from onshape_client.oas.models.bt_geometry_filter130 import BTGeometryFilter130
from onshape_client.oas.models.bt_geometry_filter130_all_of import (
    BTGeometryFilter130AllOf,
)
from onshape_client.oas.models.bt_global_tree_magic_node_info import (
    BTGlobalTreeMagicNodeInfo,
)
from onshape_client.oas.models.bt_global_tree_magic_node_info_all_of import (
    BTGlobalTreeMagicNodeInfoAllOf,
)
from onshape_client.oas.models.bt_global_tree_node_info import BTGlobalTreeNodeInfo
from onshape_client.oas.models.bt_global_tree_node_list_response import (
    BTGlobalTreeNodeListResponse,
)
from onshape_client.oas.models.bt_global_tree_node_list_response_bt_team_info import (
    BTGlobalTreeNodeListResponseBTTeamInfo,
)
from onshape_client.oas.models.bt_graphics_appearance1152 import (
    BTGraphicsAppearance1152,
)
from onshape_client.oas.models.bt_id_translation_info import BTIdTranslationInfo
from onshape_client.oas.models.bt_id_translation_params import BTIdTranslationParams
from onshape_client.oas.models.bt_id_translation_result_info import (
    BTIdTranslationResultInfo,
)
from onshape_client.oas.models.bt_identity_info import BTIdentityInfo
from onshape_client.oas.models.bt_image_filter853 import BTImageFilter853
from onshape_client.oas.models.bt_image_filter853_all_of import BTImageFilter853AllOf
from onshape_client.oas.models.bt_import import BTImport
from onshape_client.oas.models.bt_inherited_acl_info import BTInheritedAclInfo
from onshape_client.oas.models.bt_inner_array_parameter_location2368 import (
    BTInnerArrayParameterLocation2368,
)
from onshape_client.oas.models.bt_inner_array_parameter_location2368_all_of import (
    BTInnerArrayParameterLocation2368AllOf,
)
from onshape_client.oas.models.bt_inner_derived_parameter_location591 import (
    BTInnerDerivedParameterLocation591,
)
from onshape_client.oas.models.bt_inner_derived_parameter_location591_all_of import (
    BTInnerDerivedParameterLocation591AllOf,
)
from onshape_client.oas.models.bt_inner_parameter_location1715 import (
    BTInnerParameterLocation1715,
)
from onshape_client.oas.models.bt_insertable_info import BTInsertableInfo
from onshape_client.oas.models.bt_insertables_list_response import (
    BTInsertablesListResponse,
)
from onshape_client.oas.models.bt_key_mouse_values_info import BTKeyMouseValuesInfo
from onshape_client.oas.models.bt_line_description1559 import BTLineDescription1559
from onshape_client.oas.models.bt_line_description1559_all_of import (
    BTLineDescription1559AllOf,
)
from onshape_client.oas.models.bt_link_to_latest_document_info import (
    BTLinkToLatestDocumentInfo,
)
from onshape_client.oas.models.bt_link_to_latest_document_params import (
    BTLinkToLatestDocumentParams,
)
from onshape_client.oas.models.bt_list_response_bt_company_info import (
    BTListResponseBTCompanyInfo,
)
from onshape_client.oas.models.bt_list_response_bt_insertable_info import (
    BTListResponseBTInsertableInfo,
)
from onshape_client.oas.models.bt_list_response_bt_metadata_property_summary_info import (
    BTListResponseBTMetadataPropertySummaryInfo,
)
from onshape_client.oas.models.bt_list_response_bt_purchase_info import (
    BTListResponseBTPurchaseInfo,
)
from onshape_client.oas.models.bt_list_response_bt_revision_info import (
    BTListResponseBTRevisionInfo,
)
from onshape_client.oas.models.bt_list_response_bt_translation_request_info import (
    BTListResponseBTTranslationRequestInfo,
)
from onshape_client.oas.models.bt_list_response_bt_webhook_info import (
    BTListResponseBTWebhookInfo,
)
from onshape_client.oas.models.bt_location_info226 import BTLocationInfo226
from onshape_client.oas.models.bt_mass_properties_bulk_info import (
    BTMassPropertiesBulkInfo,
)
from onshape_client.oas.models.bt_mass_properties_info_null import (
    BTMassPropertiesInfoNull,
)
from onshape_client.oas.models.bt_mate_connector_cs_info import BTMateConnectorCSInfo
from onshape_client.oas.models.bt_mate_connector_filter163 import (
    BTMateConnectorFilter163,
)
from onshape_client.oas.models.bt_mate_connector_filter163_all_of import (
    BTMateConnectorFilter163AllOf,
)
from onshape_client.oas.models.bt_mate_filter162 import BTMateFilter162
from onshape_client.oas.models.bt_material_library_metadata_info import (
    BTMaterialLibraryMetadataInfo,
)
from onshape_client.oas.models.bt_material_library_settings_info import (
    BTMaterialLibrarySettingsInfo,
)
from onshape_client.oas.models.bt_material_params import BTMaterialParams
from onshape_client.oas.models.bt_material_property_params import (
    BTMaterialPropertyParams,
)
from onshape_client.oas.models.bt_metadata_category_summary_info import (
    BTMetadataCategorySummaryInfo,
)
from onshape_client.oas.models.bt_metadata_enum_value_info import (
    BTMetadataEnumValueInfo,
)
from onshape_client.oas.models.bt_metadata_property_config_summary_info import (
    BTMetadataPropertyConfigSummaryInfo,
)
from onshape_client.oas.models.bt_metadata_property_info import BTMetadataPropertyInfo
from onshape_client.oas.models.bt_metadata_property_summary_info import (
    BTMetadataPropertySummaryInfo,
)
from onshape_client.oas.models.bt_metadata_property_ui_hints_info import (
    BTMetadataPropertyUiHintsInfo,
)
from onshape_client.oas.models.bt_metadata_property_validator_info import (
    BTMetadataPropertyValidatorInfo,
)
from onshape_client.oas.models.bt_metadata_schema_info import BTMetadataSchemaInfo
from onshape_client.oas.models.bt_microversion_id366 import BTMicroversionId366
from onshape_client.oas.models.bt_microversion_id_and_configuration2338 import (
    BTMicroversionIdAndConfiguration2338,
)
from onshape_client.oas.models.bt_microversion_info import BTMicroversionInfo
from onshape_client.oas.models.bt_model_element_params import BTModelElementParams
from onshape_client.oas.models.bt_model_format_full_info import BTModelFormatFullInfo
from onshape_client.oas.models.bt_model_format_info import BTModelFormatInfo
from onshape_client.oas.models.bt_modifiable_entity_only_filter1593 import (
    BTModifiableEntityOnlyFilter1593,
)
from onshape_client.oas.models.bt_modifiable_entity_only_filter1593_all_of import (
    BTModifiableEntityOnlyFilter1593AllOf,
)
from onshape_client.oas.models.bt_move_element_info import BTMoveElementInfo
from onshape_client.oas.models.bt_move_element_params import BTMoveElementParams
from onshape_client.oas.models.bt_name_value_pair import BTNameValuePair
from onshape_client.oas.models.bt_named_view_info import BTNamedViewInfo
from onshape_client.oas.models.bt_named_views_info import BTNamedViewsInfo
from onshape_client.oas.models.bt_node_reference21 import BTNodeReference21
from onshape_client.oas.models.bt_not_filter165 import BTNotFilter165
from onshape_client.oas.models.bt_not_filter165_all_of import BTNotFilter165AllOf
from onshape_client.oas.models.bt_notice227 import BTNotice227
from onshape_client.oas.models.bt_nullable_quantity_range1340 import (
    BTNullableQuantityRange1340,
)
from onshape_client.oas.models.bt_nullable_quantity_range1340_all_of import (
    BTNullableQuantityRange1340AllOf,
)
from onshape_client.oas.models.bt_object_id import BTObjectId
from onshape_client.oas.models.bt_occurrence74 import BTOccurrence74
from onshape_client.oas.models.bt_occurrence_filter166 import BTOccurrenceFilter166
from onshape_client.oas.models.bt_occurrence_filter166_all_of import (
    BTOccurrenceFilter166AllOf,
)
from onshape_client.oas.models.bt_or_filter167 import BTOrFilter167
from onshape_client.oas.models.bt_owner3114 import BTOwner3114
from onshape_client.oas.models.bt_owner_info import BTOwnerInfo
from onshape_client.oas.models.bt_parameter_group_spec3469 import (
    BTParameterGroupSpec3469,
)
from onshape_client.oas.models.bt_parameter_lookup_table_entry1667 import (
    BTParameterLookupTableEntry1667,
)
from onshape_client.oas.models.bt_parameter_lookup_table_list_entry1916 import (
    BTParameterLookupTableListEntry1916,
)
from onshape_client.oas.models.bt_parameter_spec6 import BTParameterSpec6
from onshape_client.oas.models.bt_parameter_spec_appearance1740 import (
    BTParameterSpecAppearance1740,
)
from onshape_client.oas.models.bt_parameter_spec_array2600 import (
    BTParameterSpecArray2600,
)
from onshape_client.oas.models.bt_parameter_spec_array2600_all_of import (
    BTParameterSpecArray2600AllOf,
)
from onshape_client.oas.models.bt_parameter_spec_boolean170 import (
    BTParameterSpecBoolean170,
)
from onshape_client.oas.models.bt_parameter_spec_database1071 import (
    BTParameterSpecDatabase1071,
)
from onshape_client.oas.models.bt_parameter_spec_derived736 import (
    BTParameterSpecDerived736,
)
from onshape_client.oas.models.bt_parameter_spec_enum171 import BTParameterSpecEnum171
from onshape_client.oas.models.bt_parameter_spec_enum171_all_of import (
    BTParameterSpecEnum171AllOf,
)
from onshape_client.oas.models.bt_parameter_spec_feature_list703 import (
    BTParameterSpecFeatureList703,
)
from onshape_client.oas.models.bt_parameter_spec_foreign_id172 import (
    BTParameterSpecForeignId172,
)
from onshape_client.oas.models.bt_parameter_spec_lookup_table_path761 import (
    BTParameterSpecLookupTablePath761,
)
from onshape_client.oas.models.bt_parameter_spec_lookup_table_path761_all_of import (
    BTParameterSpecLookupTablePath761AllOf,
)
from onshape_client.oas.models.bt_parameter_spec_material2700 import (
    BTParameterSpecMaterial2700,
)
from onshape_client.oas.models.bt_parameter_spec_nullable_quantity715 import (
    BTParameterSpecNullableQuantity715,
)
from onshape_client.oas.models.bt_parameter_spec_nullable_quantity715_all_of import (
    BTParameterSpecNullableQuantity715AllOf,
)
from onshape_client.oas.models.bt_parameter_spec_quantity173 import (
    BTParameterSpecQuantity173,
)
from onshape_client.oas.models.bt_parameter_spec_quantity173_all_of import (
    BTParameterSpecQuantity173AllOf,
)
from onshape_client.oas.models.bt_parameter_spec_query174 import BTParameterSpecQuery174
from onshape_client.oas.models.bt_parameter_spec_query174_all_of import (
    BTParameterSpecQuery174AllOf,
)
from onshape_client.oas.models.bt_parameter_spec_reference2789 import (
    BTParameterSpecReference2789,
)
from onshape_client.oas.models.bt_parameter_spec_reference_assembly2821 import (
    BTParameterSpecReferenceAssembly2821,
)
from onshape_client.oas.models.bt_parameter_spec_reference_blob1367 import (
    BTParameterSpecReferenceBlob1367,
)
from onshape_client.oas.models.bt_parameter_spec_reference_cad_import1792 import (
    BTParameterSpecReferenceCADImport1792,
)
from onshape_client.oas.models.bt_parameter_spec_reference_image1722 import (
    BTParameterSpecReferenceImage1722,
)
from onshape_client.oas.models.bt_parameter_spec_reference_json1816 import (
    BTParameterSpecReferenceJSON1816,
)
from onshape_client.oas.models.bt_parameter_spec_reference_part_studio1256 import (
    BTParameterSpecReferencePartStudio1256,
)
from onshape_client.oas.models.bt_parameter_spec_reference_part_studio1256_all_of import (
    BTParameterSpecReferencePartStudio1256AllOf,
)
from onshape_client.oas.models.bt_parameter_spec_reference_table1520 import (
    BTParameterSpecReferenceTable1520,
)
from onshape_client.oas.models.bt_parameter_spec_reference_with_configuration2950 import (
    BTParameterSpecReferenceWithConfiguration2950,
)
from onshape_client.oas.models.bt_parameter_spec_reference_with_configuration2950_all_of import (
    BTParameterSpecReferenceWithConfiguration2950AllOf,
)
from onshape_client.oas.models.bt_parameter_spec_string175 import (
    BTParameterSpecString175,
)
from onshape_client.oas.models.bt_parameter_spec_string175_all_of import (
    BTParameterSpecString175AllOf,
)
from onshape_client.oas.models.bt_parameter_visibility_always_hidden176 import (
    BTParameterVisibilityAlwaysHidden176,
)
from onshape_client.oas.models.bt_parameter_visibility_condition177 import (
    BTParameterVisibilityCondition177,
)
from onshape_client.oas.models.bt_parameter_visibility_logical178 import (
    BTParameterVisibilityLogical178,
)
from onshape_client.oas.models.bt_parameter_visibility_logical178_all_of import (
    BTParameterVisibilityLogical178AllOf,
)
from onshape_client.oas.models.bt_parameter_visibility_on_equal180 import (
    BTParameterVisibilityOnEqual180,
)
from onshape_client.oas.models.bt_parameter_visibility_on_equal180_all_of import (
    BTParameterVisibilityOnEqual180AllOf,
)
from onshape_client.oas.models.bt_parameter_visibility_on_mate_dof_type2114 import (
    BTParameterVisibilityOnMateDOFType2114,
)
from onshape_client.oas.models.bt_part_appearance_info import BTPartAppearanceInfo
from onshape_client.oas.models.bt_part_appearance_params import BTPartAppearanceParams
from onshape_client.oas.models.bt_part_material1445 import BTPartMaterial1445
from onshape_client.oas.models.bt_part_material_info import BTPartMaterialInfo
from onshape_client.oas.models.bt_part_material_property1453 import (
    BTPartMaterialProperty1453,
)
from onshape_client.oas.models.bt_part_material_property_info import (
    BTPartMaterialPropertyInfo,
)
from onshape_client.oas.models.bt_part_metadata_info import BTPartMetadataInfo
from onshape_client.oas.models.bt_plan_subscriber_info import BTPlanSubscriberInfo
from onshape_client.oas.models.bt_plane_description692 import BTPlaneDescription692
from onshape_client.oas.models.bt_plane_description692_all_of import (
    BTPlaneDescription692AllOf,
)
from onshape_client.oas.models.bt_plane_orientation_filter1700 import (
    BTPlaneOrientationFilter1700,
)
from onshape_client.oas.models.bt_plane_orientation_filter1700_all_of import (
    BTPlaneOrientationFilter1700AllOf,
)
from onshape_client.oas.models.bt_project_info import BTProjectInfo
from onshape_client.oas.models.bt_property_value_param import BTPropertyValueParam
from onshape_client.oas.models.bt_published_workflow_id import BTPublishedWorkflowId
from onshape_client.oas.models.bt_published_workflow_info import BTPublishedWorkflowInfo
from onshape_client.oas.models.bt_purchase_info import BTPurchaseInfo
from onshape_client.oas.models.bt_purchase_user_params import BTPurchaseUserParams
from onshape_client.oas.models.bt_quantity_range181 import BTQuantityRange181
from onshape_client.oas.models.bt_query_filter183 import BTQueryFilter183
from onshape_client.oas.models.bt_rbac_permission_scheme_info import (
    BTRbacPermissionSchemeInfo,
)
from onshape_client.oas.models.bt_rbac_role_info import BTRbacRoleInfo
from onshape_client.oas.models.bt_release_comment_list_info import (
    BTReleaseCommentListInfo,
)
from onshape_client.oas.models.bt_release_package_info import BTReleasePackageInfo
from onshape_client.oas.models.bt_release_package_item_error import (
    BTReleasePackageItemError,
)
from onshape_client.oas.models.bt_release_package_item_info import (
    BTReleasePackageItemInfo,
)
from onshape_client.oas.models.bt_release_package_item_params import (
    BTReleasePackageItemParams,
)
from onshape_client.oas.models.bt_release_package_params import BTReleasePackageParams
from onshape_client.oas.models.bt_revision_approver_info import BTRevisionApproverInfo
from onshape_client.oas.models.bt_revision_info import BTRevisionInfo
from onshape_client.oas.models.bt_root_assembly_info import BTRootAssemblyInfo
from onshape_client.oas.models.bt_root_diff_info import BTRootDiffInfo
from onshape_client.oas.models.bt_section_plane_info import BTSectionPlaneInfo
from onshape_client.oas.models.bt_set_feature_rollback_call1899 import (
    BTSetFeatureRollbackCall1899,
)
from onshape_client.oas.models.bt_set_feature_rollback_call1899_all_of import (
    BTSetFeatureRollbackCall1899AllOf,
)
from onshape_client.oas.models.bt_set_feature_rollback_response1042 import (
    BTSetFeatureRollbackResponse1042,
)
from onshape_client.oas.models.bt_setting_info import BTSettingInfo
from onshape_client.oas.models.bt_setting_param import BTSettingParam
from onshape_client.oas.models.bt_shaded_views_info import BTShadedViewsInfo
from onshape_client.oas.models.bt_share_entry_params import BTShareEntryParams
from onshape_client.oas.models.bt_share_params import BTShareParams
from onshape_client.oas.models.bt_sketch_object_filter184 import BTSketchObjectFilter184
from onshape_client.oas.models.bt_sketch_object_filter184_all_of import (
    BTSketchObjectFilter184AllOf,
)
from onshape_client.oas.models.bt_sphere_description1263 import BTSphereDescription1263
from onshape_client.oas.models.bt_sphere_description1263_all_of import (
    BTSphereDescription1263AllOf,
)
from onshape_client.oas.models.bt_spline_description2118 import BTSplineDescription2118
from onshape_client.oas.models.bt_spline_description2118_all_of import (
    BTSplineDescription2118AllOf,
)
from onshape_client.oas.models.bt_spun_description657 import BTSpunDescription657
from onshape_client.oas.models.bt_spun_description657_all_of import (
    BTSpunDescription657AllOf,
)
from onshape_client.oas.models.bt_string_format_block_pattern1755 import (
    BTStringFormatBlockPattern1755,
)
from onshape_client.oas.models.bt_string_format_block_pattern1755_all_of import (
    BTStringFormatBlockPattern1755AllOf,
)
from onshape_client.oas.models.bt_string_format_condition683 import (
    BTStringFormatCondition683,
)
from onshape_client.oas.models.bt_string_format_match_pattern2446 import (
    BTStringFormatMatchPattern2446,
)
from onshape_client.oas.models.bt_string_format_match_pattern2446_all_of import (
    BTStringFormatMatchPattern2446AllOf,
)
from onshape_client.oas.models.bt_string_maximum_length_pattern2593 import (
    BTStringMaximumLengthPattern2593,
)
from onshape_client.oas.models.bt_string_maximum_length_pattern2593_all_of import (
    BTStringMaximumLengthPattern2593AllOf,
)
from onshape_client.oas.models.bt_string_minimum_length_pattern895 import (
    BTStringMinimumLengthPattern895,
)
from onshape_client.oas.models.bt_string_minimum_length_pattern895_all_of import (
    BTStringMinimumLengthPattern895AllOf,
)
from onshape_client.oas.models.bt_sub_assembly_info import BTSubAssemblyInfo
from onshape_client.oas.models.bt_substitute_approver_info import (
    BTSubstituteApproverInfo,
)
from onshape_client.oas.models.bt_surface_description1564 import (
    BTSurfaceDescription1564,
)
from onshape_client.oas.models.bt_sweep_description1473 import BTSweepDescription1473
from onshape_client.oas.models.bt_sweep_description1473_all_of import (
    BTSweepDescription1473AllOf,
)
from onshape_client.oas.models.bt_table1825 import BTTable1825
from onshape_client.oas.models.bt_table_assembly_cross_highlight_data2675 import (
    BTTableAssemblyCrossHighlightData2675,
)
from onshape_client.oas.models.bt_table_assembly_cross_highlight_data_item2659 import (
    BTTableAssemblyCrossHighlightDataItem2659,
)
from onshape_client.oas.models.bt_table_base_cross_highlight_data2609 import (
    BTTableBaseCrossHighlightData2609,
)
from onshape_client.oas.models.bt_table_base_row_metadata3181 import (
    BTTableBaseRowMetadata3181,
)
from onshape_client.oas.models.bt_table_cell1114 import BTTableCell1114
from onshape_client.oas.models.bt_table_cell_parameter2399 import (
    BTTableCellParameter2399,
)
from onshape_client.oas.models.bt_table_cell_parameter2399_all_of import (
    BTTableCellParameter2399AllOf,
)
from onshape_client.oas.models.bt_table_cell_property_parameter2983 import (
    BTTableCellPropertyParameter2983,
)
from onshape_client.oas.models.bt_table_cell_property_parameter2983_all_of import (
    BTTableCellPropertyParameter2983AllOf,
)
from onshape_client.oas.models.bt_table_column_info1222 import BTTableColumnInfo1222
from onshape_client.oas.models.bt_table_column_spec1967 import BTTableColumnSpec1967
from onshape_client.oas.models.bt_table_cross_highlight_data1753 import (
    BTTableCrossHighlightData1753,
)
from onshape_client.oas.models.bt_table_response1546 import BTTableResponse1546
from onshape_client.oas.models.bt_table_row1054 import BTTableRow1054
from onshape_client.oas.models.bt_table_spec915 import BTTableSpec915
from onshape_client.oas.models.bt_table_test_cell_double2509 import (
    BTTableTestCellDouble2509,
)
from onshape_client.oas.models.bt_table_test_cell_double2509_all_of import (
    BTTableTestCellDouble2509AllOf,
)
from onshape_client.oas.models.bt_table_test_cell_string2112 import (
    BTTableTestCellString2112,
)
from onshape_client.oas.models.bt_table_test_cell_string2112_all_of import (
    BTTableTestCellString2112AllOf,
)
from onshape_client.oas.models.bt_team_info import BTTeamInfo
from onshape_client.oas.models.bt_team_info_all_of import BTTeamInfoAllOf
from onshape_client.oas.models.bt_team_summary_info import BTTeamSummaryInfo
from onshape_client.oas.models.bt_text_object_filter1515 import BTTextObjectFilter1515
from onshape_client.oas.models.bt_text_object_filter1515_all_of import (
    BTTextObjectFilter1515AllOf,
)
from onshape_client.oas.models.bt_text_stroke_filter461 import BTTextStrokeFilter461
from onshape_client.oas.models.bt_text_stroke_filter461_all_of import (
    BTTextStrokeFilter461AllOf,
)
from onshape_client.oas.models.bt_thumbnail_info import BTThumbnailInfo
from onshape_client.oas.models.bt_thumbnail_size_info import BTThumbnailSizeInfo
from onshape_client.oas.models.bt_torus_description1834 import BTTorusDescription1834
from onshape_client.oas.models.bt_torus_description1834_all_of import (
    BTTorusDescription1834AllOf,
)
from onshape_client.oas.models.bt_translate_format_params import BTTranslateFormatParams
from onshape_client.oas.models.bt_translation_request_info import (
    BTTranslationRequestInfo,
)
from onshape_client.oas.models.bt_translation_request_params import (
    BTTranslationRequestParams,
)
from onshape_client.oas.models.bt_tree_node20 import BTTreeNode20
from onshape_client.oas.models.bt_unique_document_item_params import (
    BTUniqueDocumentItemParams,
)
from onshape_client.oas.models.bt_units_display_precision import BTUnitsDisplayPrecision
from onshape_client.oas.models.bt_units_maximum_display_precision_info import (
    BTUnitsMaximumDisplayPrecisionInfo,
)
from onshape_client.oas.models.bt_update_features_call1748 import (
    BTUpdateFeaturesCall1748,
)
from onshape_client.oas.models.bt_update_features_call1748_all_of import (
    BTUpdateFeaturesCall1748AllOf,
)
from onshape_client.oas.models.bt_update_features_response1333 import (
    BTUpdateFeaturesResponse1333,
)
from onshape_client.oas.models.bt_update_features_response1333_all_of import (
    BTUpdateFeaturesResponse1333AllOf,
)
from onshape_client.oas.models.bt_update_mesh_units_params import (
    BTUpdateMeshUnitsParams,
)
from onshape_client.oas.models.bt_update_reference_params import BTUpdateReferenceParams
from onshape_client.oas.models.bt_update_release_package_params import (
    BTUpdateReleasePackageParams,
)
from onshape_client.oas.models.bt_update_workflowable_test_object_params import (
    BTUpdateWorkflowableTestObjectParams,
)
from onshape_client.oas.models.bt_user_app_settings_info import BTUserAppSettingsInfo
from onshape_client.oas.models.bt_user_app_settings_params import (
    BTUserAppSettingsParams,
)
from onshape_client.oas.models.bt_user_basic_summary_info import BTUserBasicSummaryInfo
from onshape_client.oas.models.bt_user_o_auth2_summary_info import (
    BTUserOAuth2SummaryInfo,
)
from onshape_client.oas.models.bt_user_settings_info import BTUserSettingsInfo
from onshape_client.oas.models.bt_user_summary_info import BTUserSummaryInfo
from onshape_client.oas.models.bt_user_summary_info_all_of import BTUserSummaryInfoAllOf
from onshape_client.oas.models.bt_vector2d1812 import BTVector2d1812
from onshape_client.oas.models.bt_vector3d389 import BTVector3d389
from onshape_client.oas.models.bt_version_info import BTVersionInfo
from onshape_client.oas.models.bt_version_info_all_of import BTVersionInfoAllOf
from onshape_client.oas.models.bt_version_info_base import BTVersionInfoBase
from onshape_client.oas.models.bt_version_info_base_all_of import BTVersionInfoBaseAllOf
from onshape_client.oas.models.bt_version_or_workspace_info import (
    BTVersionOrWorkspaceInfo,
)
from onshape_client.oas.models.bt_version_or_workspace_params import (
    BTVersionOrWorkspaceParams,
)
from onshape_client.oas.models.bt_view_data_info import BTViewDataInfo
from onshape_client.oas.models.bt_view_manipulation_mouse_key_mapping_info import (
    BTViewManipulationMouseKeyMappingInfo,
)
from onshape_client.oas.models.bt_webhook_info import BTWebhookInfo
from onshape_client.oas.models.bt_webhook_options import BTWebhookOptions
from onshape_client.oas.models.bt_webhook_params import BTWebhookParams
from onshape_client.oas.models.bt_workflow_action_info import BTWorkflowActionInfo
from onshape_client.oas.models.bt_workflow_property_info import BTWorkflowPropertyInfo
from onshape_client.oas.models.bt_workflow_snapshot_info import BTWorkflowSnapshotInfo
from onshape_client.oas.models.bt_workflow_state_info import BTWorkflowStateInfo
from onshape_client.oas.models.bt_workflowable_test_object_info import (
    BTWorkflowableTestObjectInfo,
)
from onshape_client.oas.models.bt_workspace_info import BTWorkspaceInfo
from onshape_client.oas.models.bt_workspace_part_params import BTWorkspacePartParams
from onshape_client.oas.models.btapi_application_summary_info import (
    BTAPIApplicationSummaryInfo,
)
from onshape_client.oas.models.btfs_table953 import BTFSTable953
from onshape_client.oas.models.btfs_table953_all_of import BTFSTable953AllOf
from onshape_client.oas.models.btfs_table_column_info623 import BTFSTableColumnInfo623
from onshape_client.oas.models.btfs_table_row_metadata2262 import (
    BTFSTableRowMetadata2262,
)
from onshape_client.oas.models.btfs_table_row_metadata2262_all_of import (
    BTFSTableRowMetadata2262AllOf,
)
from onshape_client.oas.models.btfs_value1888 import BTFSValue1888
from onshape_client.oas.models.btfs_value_array1499 import BTFSValueArray1499
from onshape_client.oas.models.btfs_value_array1499_all_of import (
    BTFSValueArray1499AllOf,
)
from onshape_client.oas.models.btfs_value_boolean1195 import BTFSValueBoolean1195
from onshape_client.oas.models.btfs_value_boolean1195_all_of import (
    BTFSValueBoolean1195AllOf,
)
from onshape_client.oas.models.btfs_value_map2062 import BTFSValueMap2062
from onshape_client.oas.models.btfs_value_map_entry2077 import BTFSValueMapEntry2077
from onshape_client.oas.models.btfs_value_number772 import BTFSValueNumber772
from onshape_client.oas.models.btfs_value_number772_all_of import (
    BTFSValueNumber772AllOf,
)
from onshape_client.oas.models.btfs_value_other1124 import BTFSValueOther1124
from onshape_client.oas.models.btfs_value_other1124_all_of import (
    BTFSValueOther1124AllOf,
)
from onshape_client.oas.models.btfs_value_string1422 import BTFSValueString1422
from onshape_client.oas.models.btfs_value_string1422_all_of import (
    BTFSValueString1422AllOf,
)
from onshape_client.oas.models.btfs_value_too_big1247 import BTFSValueTooBig1247
from onshape_client.oas.models.btfs_value_undefined2003 import BTFSValueUndefined2003
from onshape_client.oas.models.btfs_value_with_units1817 import BTFSValueWithUnits1817
from onshape_client.oas.models.btfs_value_with_units1817_all_of import (
    BTFSValueWithUnits1817AllOf,
)
from onshape_client.oas.models.btm_array_parameter_item1843 import (
    BTMArrayParameterItem1843,
)
from onshape_client.oas.models.btm_assembly_feature12218 import BTMAssemblyFeature12218
from onshape_client.oas.models.btm_assembly_feature21022 import BTMAssemblyFeature21022
from onshape_client.oas.models.btm_assembly_feature887 import BTMAssemblyFeature887
from onshape_client.oas.models.btm_assembly_feature887_all_of import (
    BTMAssemblyFeature887AllOf,
)
from onshape_client.oas.models.btm_assembly_pattern_feature2241 import (
    BTMAssemblyPatternFeature2241,
)
from onshape_client.oas.models.btm_assembly_pattern_feature2241_all_of import (
    BTMAssemblyPatternFeature2241AllOf,
)
from onshape_client.oas.models.btm_configuration_parameter819 import (
    BTMConfigurationParameter819,
)
from onshape_client.oas.models.btm_configuration_parameter_boolean2550 import (
    BTMConfigurationParameterBoolean2550,
)
from onshape_client.oas.models.btm_configuration_parameter_boolean2550_all_of import (
    BTMConfigurationParameterBoolean2550AllOf,
)
from onshape_client.oas.models.btm_configuration_parameter_enum105 import (
    BTMConfigurationParameterEnum105,
)
from onshape_client.oas.models.btm_configuration_parameter_enum105_all_of import (
    BTMConfigurationParameterEnum105AllOf,
)
from onshape_client.oas.models.btm_configuration_parameter_quantity1826 import (
    BTMConfigurationParameterQuantity1826,
)
from onshape_client.oas.models.btm_configuration_parameter_quantity1826_all_of import (
    BTMConfigurationParameterQuantity1826AllOf,
)
from onshape_client.oas.models.btm_configuration_parameter_string872 import (
    BTMConfigurationParameterString872,
)
from onshape_client.oas.models.btm_configuration_parameter_string872_all_of import (
    BTMConfigurationParameterString872AllOf,
)
from onshape_client.oas.models.btm_configured_value1341 import BTMConfiguredValue1341
from onshape_client.oas.models.btm_configured_value_by_boolean1501 import (
    BTMConfiguredValueByBoolean1501,
)
from onshape_client.oas.models.btm_configured_value_by_boolean1501_all_of import (
    BTMConfiguredValueByBoolean1501AllOf,
)
from onshape_client.oas.models.btm_configured_value_by_enum1923 import (
    BTMConfiguredValueByEnum1923,
)
from onshape_client.oas.models.btm_configured_value_by_enum1923_all_of import (
    BTMConfiguredValueByEnum1923AllOf,
)
from onshape_client.oas.models.btm_database_parameter2229 import (
    BTMDatabaseParameter2229,
)
from onshape_client.oas.models.btm_database_parameter2229_all_of import (
    BTMDatabaseParameter2229AllOf,
)
from onshape_client.oas.models.btm_enum_option592 import BTMEnumOption592
from onshape_client.oas.models.btm_feature134 import BTMFeature134
from onshape_client.oas.models.btm_feature_invalid1031 import BTMFeatureInvalid1031
from onshape_client.oas.models.btm_feature_query_with_occurrence157 import (
    BTMFeatureQueryWithOccurrence157,
)
from onshape_client.oas.models.btm_feature_query_with_occurrence157_all_of import (
    BTMFeatureQueryWithOccurrence157AllOf,
)
from onshape_client.oas.models.btm_geometry_mate1260 import BTMGeometryMate1260
from onshape_client.oas.models.btm_import136 import BTMImport136
from onshape_client.oas.models.btm_in_context_query2254 import BTMInContextQuery2254
from onshape_client.oas.models.btm_in_context_query2254_all_of import (
    BTMInContextQuery2254AllOf,
)
from onshape_client.oas.models.btm_individual_co_edge_query1332 import (
    BTMIndividualCoEdgeQuery1332,
)
from onshape_client.oas.models.btm_individual_co_edge_query1332_all_of import (
    BTMIndividualCoEdgeQuery1332AllOf,
)
from onshape_client.oas.models.btm_individual_created_by_query137 import (
    BTMIndividualCreatedByQuery137,
)
from onshape_client.oas.models.btm_individual_created_by_query137_all_of import (
    BTMIndividualCreatedByQuery137AllOf,
)
from onshape_client.oas.models.btm_individual_occurrence_query626 import (
    BTMIndividualOccurrenceQuery626,
)
from onshape_client.oas.models.btm_individual_query138 import BTMIndividualQuery138
from onshape_client.oas.models.btm_individual_query138_all_of import (
    BTMIndividualQuery138AllOf,
)
from onshape_client.oas.models.btm_individual_query_base139 import (
    BTMIndividualQueryBase139,
)
from onshape_client.oas.models.btm_individual_query_with_occurrence811 import (
    BTMIndividualQueryWithOccurrence811,
)
from onshape_client.oas.models.btm_individual_query_with_occurrence811_all_of import (
    BTMIndividualQueryWithOccurrence811AllOf,
)
from onshape_client.oas.models.btm_individual_query_with_occurrence_base904 import (
    BTMIndividualQueryWithOccurrenceBase904,
)
from onshape_client.oas.models.btm_individual_sketch_region_query140 import (
    BTMIndividualSketchRegionQuery140,
)
from onshape_client.oas.models.btm_individual_sketch_region_query140_all_of import (
    BTMIndividualSketchRegionQuery140AllOf,
)
from onshape_client.oas.models.btm_individual_sketch_unique_vertices_query1472 import (
    BTMIndividualSketchUniqueVerticesQuery1472,
)
from onshape_client.oas.models.btm_individual_sketch_unique_vertices_query1472_all_of import (
    BTMIndividualSketchUniqueVerticesQuery1472AllOf,
)
from onshape_client.oas.models.btm_inference_query_with_occurrence1083 import (
    BTMInferenceQueryWithOccurrence1083,
)
from onshape_client.oas.models.btm_inference_query_with_occurrence1083_all_of import (
    BTMInferenceQueryWithOccurrence1083AllOf,
)
from onshape_client.oas.models.btm_mate64 import BTMMate64
from onshape_client.oas.models.btm_mate64_all_of import BTMMate64AllOf
from onshape_client.oas.models.btm_mate_connector66 import BTMMateConnector66
from onshape_client.oas.models.btm_mate_connector66_all_of import (
    BTMMateConnector66AllOf,
)
from onshape_client.oas.models.btm_mate_group65 import BTMMateGroup65
from onshape_client.oas.models.btm_mate_relation1412 import BTMMateRelation1412
from onshape_client.oas.models.btm_non_geometric_item1864 import BTMNonGeometricItem1864
from onshape_client.oas.models.btm_non_geometric_item1864_all_of import (
    BTMNonGeometricItem1864AllOf,
)
from onshape_client.oas.models.btm_parameter1 import BTMParameter1
from onshape_client.oas.models.btm_parameter_appearance627 import (
    BTMParameterAppearance627,
)
from onshape_client.oas.models.btm_parameter_appearance627_all_of import (
    BTMParameterAppearance627AllOf,
)
from onshape_client.oas.models.btm_parameter_array2025 import BTMParameterArray2025
from onshape_client.oas.models.btm_parameter_array2025_all_of import (
    BTMParameterArray2025AllOf,
)
from onshape_client.oas.models.btm_parameter_blob_reference1679 import (
    BTMParameterBlobReference1679,
)
from onshape_client.oas.models.btm_parameter_blob_reference1679_all_of import (
    BTMParameterBlobReference1679AllOf,
)
from onshape_client.oas.models.btm_parameter_boolean144 import BTMParameterBoolean144
from onshape_client.oas.models.btm_parameter_boolean144_all_of import (
    BTMParameterBoolean144AllOf,
)
from onshape_client.oas.models.btm_parameter_configured2222 import (
    BTMParameterConfigured2222,
)
from onshape_client.oas.models.btm_parameter_configured2222_all_of import (
    BTMParameterConfigured2222AllOf,
)
from onshape_client.oas.models.btm_parameter_derived864 import BTMParameterDerived864
from onshape_client.oas.models.btm_parameter_derived864_all_of import (
    BTMParameterDerived864AllOf,
)
from onshape_client.oas.models.btm_parameter_enum145 import BTMParameterEnum145
from onshape_client.oas.models.btm_parameter_enum145_all_of import (
    BTMParameterEnum145AllOf,
)
from onshape_client.oas.models.btm_parameter_feature_list1749 import (
    BTMParameterFeatureList1749,
)
from onshape_client.oas.models.btm_parameter_feature_list1749_all_of import (
    BTMParameterFeatureList1749AllOf,
)
from onshape_client.oas.models.btm_parameter_foreign_id146 import (
    BTMParameterForeignId146,
)
from onshape_client.oas.models.btm_parameter_foreign_id146_all_of import (
    BTMParameterForeignId146AllOf,
)
from onshape_client.oas.models.btm_parameter_invalid1664 import BTMParameterInvalid1664
from onshape_client.oas.models.btm_parameter_lookup_table_path1419 import (
    BTMParameterLookupTablePath1419,
)
from onshape_client.oas.models.btm_parameter_lookup_table_path1419_all_of import (
    BTMParameterLookupTablePath1419AllOf,
)
from onshape_client.oas.models.btm_parameter_material1388 import (
    BTMParameterMaterial1388,
)
from onshape_client.oas.models.btm_parameter_material1388_all_of import (
    BTMParameterMaterial1388AllOf,
)
from onshape_client.oas.models.btm_parameter_nullable_quantity807 import (
    BTMParameterNullableQuantity807,
)
from onshape_client.oas.models.btm_parameter_nullable_quantity807_all_of import (
    BTMParameterNullableQuantity807AllOf,
)
from onshape_client.oas.models.btm_parameter_quantity147 import BTMParameterQuantity147
from onshape_client.oas.models.btm_parameter_quantity147_all_of import (
    BTMParameterQuantity147AllOf,
)
from onshape_client.oas.models.btm_parameter_query_list148 import (
    BTMParameterQueryList148,
)
from onshape_client.oas.models.btm_parameter_query_list148_all_of import (
    BTMParameterQueryList148AllOf,
)
from onshape_client.oas.models.btm_parameter_query_with_occurrence_list67 import (
    BTMParameterQueryWithOccurrenceList67,
)
from onshape_client.oas.models.btm_parameter_query_with_occurrence_list67_all_of import (
    BTMParameterQueryWithOccurrenceList67AllOf,
)
from onshape_client.oas.models.btm_parameter_reference2434 import (
    BTMParameterReference2434,
)
from onshape_client.oas.models.btm_parameter_reference2434_all_of import (
    BTMParameterReference2434AllOf,
)
from onshape_client.oas.models.btm_parameter_reference_assembly938 import (
    BTMParameterReferenceAssembly938,
)
from onshape_client.oas.models.btm_parameter_reference_blob3281 import (
    BTMParameterReferenceBlob3281,
)
from onshape_client.oas.models.btm_parameter_reference_cad_import2016 import (
    BTMParameterReferenceCADImport2016,
)
from onshape_client.oas.models.btm_parameter_reference_image2014 import (
    BTMParameterReferenceImage2014,
)
from onshape_client.oas.models.btm_parameter_reference_json790 import (
    BTMParameterReferenceJSON790,
)
from onshape_client.oas.models.btm_parameter_reference_part_studio3302 import (
    BTMParameterReferencePartStudio3302,
)
from onshape_client.oas.models.btm_parameter_reference_part_studio3302_all_of import (
    BTMParameterReferencePartStudio3302AllOf,
)
from onshape_client.oas.models.btm_parameter_reference_table917 import (
    BTMParameterReferenceTable917,
)
from onshape_client.oas.models.btm_parameter_reference_with_configuration3028 import (
    BTMParameterReferenceWithConfiguration3028,
)
from onshape_client.oas.models.btm_parameter_string149 import BTMParameterString149
from onshape_client.oas.models.btm_parameter_string149_all_of import (
    BTMParameterString149AllOf,
)
from onshape_client.oas.models.btm_part_studio_mate_connector_query1324 import (
    BTMPartStudioMateConnectorQuery1324,
)
from onshape_client.oas.models.btm_sketch151 import BTMSketch151
from onshape_client.oas.models.btm_sketch151_all_of import BTMSketch151AllOf
from onshape_client.oas.models.btm_sketch_constraint2 import BTMSketchConstraint2
from onshape_client.oas.models.btm_sketch_curve4 import BTMSketchCurve4
from onshape_client.oas.models.btm_sketch_curve4_all_of import BTMSketchCurve4AllOf
from onshape_client.oas.models.btm_sketch_curve_segment155 import (
    BTMSketchCurveSegment155,
)
from onshape_client.oas.models.btm_sketch_curve_segment155_all_of import (
    BTMSketchCurveSegment155AllOf,
)
from onshape_client.oas.models.btm_sketch_geom_entity5 import BTMSketchGeomEntity5
from onshape_client.oas.models.btm_sketch_image_entity763 import BTMSketchImageEntity763
from onshape_client.oas.models.btm_sketch_image_entity763_all_of import (
    BTMSketchImageEntity763AllOf,
)
from onshape_client.oas.models.btm_sketch_point158 import BTMSketchPoint158
from onshape_client.oas.models.btm_sketch_point158_all_of import BTMSketchPoint158AllOf
from onshape_client.oas.models.btm_sketch_text_entity1761 import BTMSketchTextEntity1761
from onshape_client.oas.models.btm_sketch_text_entity1761_all_of import (
    BTMSketchTextEntity1761AllOf,
)
from onshape_client.oas.models.btp_annotation231 import BTPAnnotation231
from onshape_client.oas.models.btp_argument_declaration232 import (
    BTPArgumentDeclaration232,
)
from onshape_client.oas.models.btp_argument_declaration232_all_of import (
    BTPArgumentDeclaration232AllOf,
)
from onshape_client.oas.models.btp_builtin_identifier233 import BTPBuiltinIdentifier233
from onshape_client.oas.models.btp_builtin_identifier233_all_of import (
    BTPBuiltinIdentifier233AllOf,
)
from onshape_client.oas.models.btp_conversion_function1362 import (
    BTPConversionFunction1362,
)
from onshape_client.oas.models.btp_conversion_function1362_all_of import (
    BTPConversionFunction1362AllOf,
)
from onshape_client.oas.models.btp_expression9 import BTPExpression9
from onshape_client.oas.models.btp_expression_access237 import BTPExpressionAccess237
from onshape_client.oas.models.btp_expression_access237_all_of import (
    BTPExpressionAccess237AllOf,
)
from onshape_client.oas.models.btp_expression_as238 import BTPExpressionAs238
from onshape_client.oas.models.btp_expression_as238_all_of import (
    BTPExpressionAs238AllOf,
)
from onshape_client.oas.models.btp_expression_builtin_call239 import (
    BTPExpressionBuiltinCall239,
)
from onshape_client.oas.models.btp_expression_builtin_call239_all_of import (
    BTPExpressionBuiltinCall239AllOf,
)
from onshape_client.oas.models.btp_expression_call240 import BTPExpressionCall240
from onshape_client.oas.models.btp_expression_call240_all_of import (
    BTPExpressionCall240AllOf,
)
from onshape_client.oas.models.btp_expression_function1325 import (
    BTPExpressionFunction1325,
)
from onshape_client.oas.models.btp_expression_function1325_all_of import (
    BTPExpressionFunction1325AllOf,
)
from onshape_client.oas.models.btp_expression_group241 import BTPExpressionGroup241
from onshape_client.oas.models.btp_expression_group241_all_of import (
    BTPExpressionGroup241AllOf,
)
from onshape_client.oas.models.btp_expression_is242 import BTPExpressionIs242
from onshape_client.oas.models.btp_expression_new243 import BTPExpressionNew243
from onshape_client.oas.models.btp_expression_new243_all_of import (
    BTPExpressionNew243AllOf,
)
from onshape_client.oas.models.btp_expression_operator244 import (
    BTPExpressionOperator244,
)
from onshape_client.oas.models.btp_expression_operator244_all_of import (
    BTPExpressionOperator244AllOf,
)
from onshape_client.oas.models.btp_expression_switch2632 import BTPExpressionSwitch2632
from onshape_client.oas.models.btp_expression_switch2632_all_of import (
    BTPExpressionSwitch2632AllOf,
)
from onshape_client.oas.models.btp_expression_try1271 import BTPExpressionTry1271
from onshape_client.oas.models.btp_expression_try1271_all_of import (
    BTPExpressionTry1271AllOf,
)
from onshape_client.oas.models.btp_expression_var_reference245 import (
    BTPExpressionVarReference245,
)
from onshape_client.oas.models.btp_expression_var_reference245_all_of import (
    BTPExpressionVarReference245AllOf,
)
from onshape_client.oas.models.btp_function_declaration246 import (
    BTPFunctionDeclaration246,
)
from onshape_client.oas.models.btp_function_or_predicate_declaration247 import (
    BTPFunctionOrPredicateDeclaration247,
)
from onshape_client.oas.models.btp_function_or_predicate_declaration247_all_of import (
    BTPFunctionOrPredicateDeclaration247AllOf,
)
from onshape_client.oas.models.btp_identifier8 import BTPIdentifier8
from onshape_client.oas.models.btp_identifier8_all_of import BTPIdentifier8AllOf
from onshape_client.oas.models.btp_literal253 import BTPLiteral253
from onshape_client.oas.models.btp_literal_array254 import BTPLiteralArray254
from onshape_client.oas.models.btp_literal_array254_all_of import (
    BTPLiteralArray254AllOf,
)
from onshape_client.oas.models.btp_literal_boolean255 import BTPLiteralBoolean255
from onshape_client.oas.models.btp_literal_map256 import BTPLiteralMap256
from onshape_client.oas.models.btp_literal_map_entry257 import BTPLiteralMapEntry257
from onshape_client.oas.models.btp_literal_map_entry257_all_of import (
    BTPLiteralMapEntry257AllOf,
)
from onshape_client.oas.models.btp_literal_number258 import BTPLiteralNumber258
from onshape_client.oas.models.btp_literal_string259 import BTPLiteralString259
from onshape_client.oas.models.btp_literal_string259_all_of import (
    BTPLiteralString259AllOf,
)
from onshape_client.oas.models.btp_literal_undefined260 import BTPLiteralUndefined260
from onshape_client.oas.models.btp_module234 import BTPModule234
from onshape_client.oas.models.btp_module234_all_of import BTPModule234AllOf
from onshape_client.oas.models.btp_module_id235 import BTPModuleId235
from onshape_client.oas.models.btp_module_id235_all_of import BTPModuleId235AllOf
from onshape_client.oas.models.btp_name261 import BTPName261
from onshape_client.oas.models.btp_name261_all_of import BTPName261AllOf
from onshape_client.oas.models.btp_node7 import BTPNode7
from onshape_client.oas.models.btp_operator_declaration264 import (
    BTPOperatorDeclaration264,
)
from onshape_client.oas.models.btp_operator_declaration264_all_of import (
    BTPOperatorDeclaration264AllOf,
)
from onshape_client.oas.models.btp_predicate_declaration265 import (
    BTPPredicateDeclaration265,
)
from onshape_client.oas.models.btp_procedure_declaration_base266 import (
    BTPProcedureDeclarationBase266,
)
from onshape_client.oas.models.btp_procedure_declaration_base266_all_of import (
    BTPProcedureDeclarationBase266AllOf,
)
from onshape_client.oas.models.btp_property_accessor23 import BTPPropertyAccessor23
from onshape_client.oas.models.btp_space10 import BTPSpace10
from onshape_client.oas.models.btp_statement269 import BTPStatement269
from onshape_client.oas.models.btp_statement269_all_of import BTPStatement269AllOf
from onshape_client.oas.models.btp_statement_assignment270 import (
    BTPStatementAssignment270,
)
from onshape_client.oas.models.btp_statement_assignment270_all_of import (
    BTPStatementAssignment270AllOf,
)
from onshape_client.oas.models.btp_statement_block271 import BTPStatementBlock271
from onshape_client.oas.models.btp_statement_block271_all_of import (
    BTPStatementBlock271AllOf,
)
from onshape_client.oas.models.btp_statement_break272 import BTPStatementBreak272
from onshape_client.oas.models.btp_statement_break272_all_of import (
    BTPStatementBreak272AllOf,
)
from onshape_client.oas.models.btp_statement_compressed_query1237 import (
    BTPStatementCompressedQuery1237,
)
from onshape_client.oas.models.btp_statement_compressed_query1237_all_of import (
    BTPStatementCompressedQuery1237AllOf,
)
from onshape_client.oas.models.btp_statement_constant_declaration273 import (
    BTPStatementConstantDeclaration273,
)
from onshape_client.oas.models.btp_statement_constant_declaration273_all_of import (
    BTPStatementConstantDeclaration273AllOf,
)
from onshape_client.oas.models.btp_statement_continue274 import BTPStatementContinue274
from onshape_client.oas.models.btp_statement_continue274_all_of import (
    BTPStatementContinue274AllOf,
)
from onshape_client.oas.models.btp_statement_expression275 import (
    BTPStatementExpression275,
)
from onshape_client.oas.models.btp_statement_expression275_all_of import (
    BTPStatementExpression275AllOf,
)
from onshape_client.oas.models.btp_statement_if276 import BTPStatementIf276
from onshape_client.oas.models.btp_statement_if276_all_of import BTPStatementIf276AllOf
from onshape_client.oas.models.btp_statement_loop277 import BTPStatementLoop277
from onshape_client.oas.models.btp_statement_loop277_all_of import (
    BTPStatementLoop277AllOf,
)
from onshape_client.oas.models.btp_statement_loop_for3278 import BTPStatementLoopFor3278
from onshape_client.oas.models.btp_statement_loop_for3278_all_of import (
    BTPStatementLoopFor3278AllOf,
)
from onshape_client.oas.models.btp_statement_loop_for_in279 import (
    BTPStatementLoopForIn279,
)
from onshape_client.oas.models.btp_statement_loop_for_in279_all_of import (
    BTPStatementLoopForIn279AllOf,
)
from onshape_client.oas.models.btp_statement_loop_while280 import (
    BTPStatementLoopWhile280,
)
from onshape_client.oas.models.btp_statement_loop_while280_all_of import (
    BTPStatementLoopWhile280AllOf,
)
from onshape_client.oas.models.btp_statement_return281 import BTPStatementReturn281
from onshape_client.oas.models.btp_statement_return281_all_of import (
    BTPStatementReturn281AllOf,
)
from onshape_client.oas.models.btp_statement_throw1080 import BTPStatementThrow1080
from onshape_client.oas.models.btp_statement_throw1080_all_of import (
    BTPStatementThrow1080AllOf,
)
from onshape_client.oas.models.btp_statement_try1523 import BTPStatementTry1523
from onshape_client.oas.models.btp_statement_try1523_all_of import (
    BTPStatementTry1523AllOf,
)
from onshape_client.oas.models.btp_statement_var_declaration282 import (
    BTPStatementVarDeclaration282,
)
from onshape_client.oas.models.btp_top_level_constant_declaration283 import (
    BTPTopLevelConstantDeclaration283,
)
from onshape_client.oas.models.btp_top_level_constant_declaration283_all_of import (
    BTPTopLevelConstantDeclaration283AllOf,
)
from onshape_client.oas.models.btp_top_level_enum_declaration284 import (
    BTPTopLevelEnumDeclaration284,
)
from onshape_client.oas.models.btp_top_level_enum_declaration284_all_of import (
    BTPTopLevelEnumDeclaration284AllOf,
)
from onshape_client.oas.models.btp_top_level_import285 import BTPTopLevelImport285
from onshape_client.oas.models.btp_top_level_import285_all_of import (
    BTPTopLevelImport285AllOf,
)
from onshape_client.oas.models.btp_top_level_node286 import BTPTopLevelNode286
from onshape_client.oas.models.btp_top_level_node286_all_of import (
    BTPTopLevelNode286AllOf,
)
from onshape_client.oas.models.btp_top_level_type_declaration287 import (
    BTPTopLevelTypeDeclaration287,
)
from onshape_client.oas.models.btp_top_level_type_declaration287_all_of import (
    BTPTopLevelTypeDeclaration287AllOf,
)
from onshape_client.oas.models.btp_top_level_user_type_declaration288 import (
    BTPTopLevelUserTypeDeclaration288,
)
from onshape_client.oas.models.btp_top_level_user_type_declaration288_all_of import (
    BTPTopLevelUserTypeDeclaration288AllOf,
)
from onshape_client.oas.models.btp_type_name290 import BTPTypeName290
from onshape_client.oas.models.btp_type_name_standard291 import BTPTypeNameStandard291
from onshape_client.oas.models.btp_type_name_user292 import BTPTypeNameUser292
from onshape_client.oas.models.btp_type_name_user292_all_of import (
    BTPTypeNameUser292AllOf,
)
from onshape_client.oas.models.btpl_value249 import BTPLValue249
from onshape_client.oas.models.btpl_value_access250 import BTPLValueAccess250
from onshape_client.oas.models.btpl_value_access250_all_of import (
    BTPLValueAccess250AllOf,
)
from onshape_client.oas.models.btpl_value_box_dereference251 import (
    BTPLValueBoxDereference251,
)
from onshape_client.oas.models.btpl_value_box_dereference251_all_of import (
    BTPLValueBoxDereference251AllOf,
)
from onshape_client.oas.models.btpl_value_var_reference252 import (
    BTPLValueVarReference252,
)
from onshape_client.oas.models.btsm_bend_table_row_metadata1705 import (
    BTSMBendTableRowMetadata1705,
)
from onshape_client.oas.models.btsm_bend_table_row_metadata1705_all_of import (
    BTSMBendTableRowMetadata1705AllOf,
)
from onshape_client.oas.models.btsm_definition_entity_type_filter1651 import (
    BTSMDefinitionEntityTypeFilter1651,
)
from onshape_client.oas.models.btsm_definition_entity_type_filter1651_all_of import (
    BTSMDefinitionEntityTypeFilter1651AllOf,
)
from onshape_client.oas.models.btsm_other_joint_table_row_metadata2640 import (
    BTSMOtherJointTableRowMetadata2640,
)
from onshape_client.oas.models.card import Card
from onshape_client.oas.models.configuration_entry import ConfigurationEntry
from onshape_client.oas.models.configuration_info_entry import ConfigurationInfoEntry
from onshape_client.oas.models.content_disposition import ContentDisposition
from onshape_client.oas.models.coupon import Coupon
from onshape_client.oas.models.customer import Customer
from onshape_client.oas.models.customer_card_collection import CustomerCardCollection
from onshape_client.oas.models.customer_subscription_collection import (
    CustomerSubscriptionCollection,
)
from onshape_client.oas.models.discount import Discount
from onshape_client.oas.models.entry import Entry
from onshape_client.oas.models.external_account import ExternalAccount
from onshape_client.oas.models.external_account_collection import (
    ExternalAccountCollection,
)
from onshape_client.oas.models.form_data_body_part import FormDataBodyPart
from onshape_client.oas.models.form_data_content_disposition import (
    FormDataContentDisposition,
)
from onshape_client.oas.models.global_permission_info import GlobalPermissionInfo
from onshape_client.oas.models.json_node import JsonNode
from onshape_client.oas.models.multi_part import MultiPart
from onshape_client.oas.models.next_charge import NextCharge
from onshape_client.oas.models.next_recurring_charge import NextRecurringCharge
from onshape_client.oas.models.parameterized_header import ParameterizedHeader
from onshape_client.oas.models.plan import Plan
from onshape_client.oas.models.prorated_charges import ProratedCharges
from onshape_client.oas.models.request_options import RequestOptions
from onshape_client.oas.models.role_map_entry import RoleMapEntry
from onshape_client.oas.models.shipping_details import ShippingDetails
from onshape_client.oas.models.subscription import Subscription
from onshape_client.oas.models.subscription_item import SubscriptionItem
from onshape_client.oas.models.subscription_item_collection import (
    SubscriptionItemCollection,
)
from onshape_client.oas.models.three_d_secure import ThreeDSecure
from onshape_client.oas.models.transform_group import TransformGroup
from onshape_client.oas.models.update_params import UpdateParams



# coding: utf-8

"""
    Onshape REST API

    The Onshape REST API consumed by all clients.  # noqa: E501

    The version of the OpenAPI document: 1.113
    Contact: api-support@onshape.zendesk.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import
import re  # noqa: F401
import sys  # noqa: F401

import six  # noqa: F401
import nulltype  # noqa: F401

from onshape_client.oas.model_utils import (  # noqa: F401
    ModelComposed,
    ModelNormal,
    ModelSimple,
    date,
    datetime,
    file_type,
    int,
    none_type,
    str,
    validate_get_composed_info,
)


class BTDocumentVersionElementIds1897(ModelNormal):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.

    Attributes:
      allowed_values (dict): The key is the tuple path to the attribute
          and the for var_name this is (var_name,). The value is a dict
          with a capitalized key describing the allowed value and an allowed
          value. These dicts store the allowed enum values.
      attribute_map (dict): The key is attribute name
          and the value is json key in definition.
      discriminator_value_class_map (dict): A dict to go from the discriminator
          variable value to the discriminator class name.
      validations (dict): The key is the tuple path to the attribute
          and the for var_name this is (var_name,). The value is a dict
          that stores validations for max_length, min_length, max_items,
          min_items, exclusive_maximum, inclusive_maximum, exclusive_minimum,
          inclusive_minimum, and regex.
      additional_properties_type (tuple): A tuple of classes accepted
          as additional properties values.
    """

    allowed_values = {}

    validations = {}

    additional_properties_type = None

    @staticmethod
    def openapi_types():
        """
        This must be a class method so a model may have properties that are
        of type self, this ensures that we don't create a cyclic import

        Returns
            openapi_types (dict): The key is attribute name
                and the value is attribute type.
        """
        return {
            "bt_type": (str,),  # noqa: E501
            "document_id": (str,),  # noqa: E501
            "element_id": (str,),  # noqa: E501
            "version_id": (str,),  # noqa: E501
        }

    @staticmethod
    def discriminator():
        return None

    attribute_map = {
        "bt_type": "btType",  # noqa: E501
        "document_id": "documentId",  # noqa: E501
        "element_id": "elementId",  # noqa: E501
        "version_id": "versionId",  # noqa: E501
    }

    @staticmethod
    def _composed_schemas():
        return None

    required_properties = set(
        [
            "_data_store",
            "_check_type",
            "_from_server",
            "_path_to_item",
            "_configuration",
        ]
    )

    def __init__(
        self,
        _check_type=True,
        _from_server=False,
        _path_to_item=(),
        _configuration=None,
        **kwargs
    ):  # noqa: E501
        """bt_document_version_element_ids1897.BTDocumentVersionElementIds1897 - a model defined in OpenAPI

        Keyword Args:
            _check_type (bool): if True, values for parameters in openapi_types
                                will be type checked and a TypeError will be
                                raised if the wrong type is input.
                                Defaults to True
            _path_to_item (tuple/list): This is a list of keys or values to
                                drill down to the model in received_data
                                when deserializing a response
            _from_server (bool): True if the data is from the server
                                False if the data is from the client (default)
            _configuration (Configuration): the instance to use when
                                deserializing a file_type parameter.
                                If passed, type conversion is attempted
                                If omitted no type conversion is done.
            bt_type (str): [optional]  # noqa: E501
            document_id (str): [optional]  # noqa: E501
            element_id (str): [optional]  # noqa: E501
            version_id (str): [optional]  # noqa: E501
        """

        self._data_store = {}
        self._check_type = _check_type
        self._from_server = _from_server
        self._path_to_item = _path_to_item
        self._configuration = _configuration

        for var_name, var_value in six.iteritems(kwargs):
            if (
                var_name not in self.attribute_map
                and self._configuration is not None
                and self._configuration.discard_unknown_keys
                and self.additional_properties_type is None
            ):
                # discard variable.
                continue
            setattr(self, var_name, var_value)



class AssemblyDefinition:
    def __init__(self, assembly_definition):
        self.assembly_definition = assembly_definition

    def get_instance(self, occurrence_path):
        assembly_definition = self.assembly_definition
        if len(occurrence_path) == 0:
            return
        occ_path = occurrence_path.copy()
        # Consume assembly-pointing occurrence path elements
        instance = self.find_instance(
            occ_path.pop(0), assembly_definition["rootAssembly"]
        )
        while len(occ_path) > 0:
            sa = self.find_sub_assembly(instance)
            instance = self.find_instance(occ_path.pop(0), sa)
        return instance

    def get_occurrence_transforms(self, occurrence_path):
        return [
            occ["transform"]
            for occ in self.assembly_definition["rootAssembly"]["occurrences"]
            if occ["path"] == occurrence_path
        ]

    def find_occurrence_paths(self, instance):
        paths = []
        for occ in self.assembly_definition["rootAssembly"]["occurrences"]:
            potential_path = occ["path"]
            potential_instance = self.get_instance(potential_path)
            if self.is_equal_element_content(instance, potential_instance):
                paths.append(potential_path)
        return paths

    def find_instance(self, instance_id, sa):
        return next(
            instance for instance in sa["instances"] if instance["id"] == instance_id
        )

    def find_sub_assembly(self, instance):
        assembly_definition = self.assembly_definition
        for sa in assembly_definition["subAssemblies"]:
            if self.is_equal_element_content(sa, instance):
                return sa
        return None

    @staticmethod
    def compare_configurations(this, other):
        return set(this.split(";")) == set(other.split(";"))

    @staticmethod
    def is_equal_element_content(this, other):
        return (
            this["documentMicroversion"] == other["documentMicroversion"]
            and this["elementId"] == other["elementId"]
            and AssemblyDefinition.compare_configurations(
                this["configuration"], other["configuration"]
            )
        )



import pytest
import socket
from requests import get
from pyngrok import ngrok
import webbrowser
from typing import Callable
from http.server import BaseHTTPRequestHandler, HTTPServer
from threading import Thread
import six
import json
import time
import queue
from onshape_client.oas import (
    BTWebhookParams,
    BTWebhookOptions,
    BTTranslateFormatParams,
)
from onshape_client.onshape_url import OnshapeElement

import socket
from contextlib import closing


@pytest.fixture
def free_port():
    with closing(socket.socket(socket.AF_INET, socket.SOCK_STREAM)) as s:
        s.bind(("", 0))
        s.setsockopt(socket.SOL_SOCKET, socket.SO_REUSEADDR, 1)
        return s.getsockname()[1]


def tunnel(port):
    """Open a tunnel and return the public URL."""
    url = ngrok.connect(port=port)
    return url


@pytest.fixture
def webhook_server_factory(free_port):
    """For making a server that can accept Onshape webhooks."""

    servers = []
    threads = []

    def _webhook_server_factory():
        """ Create a factory to handle webhook notifications coming in.
        :param on_recieved: function callback to handle the json response from the webhook.
        :return: HTTPServer: server
        """

        class myHandler(BaseHTTPRequestHandler):
            def __init__(self, request, client_address, server):
                super().__init__(request, client_address, server)
                # Holds function that deals with the request.
                self.on_recieved = None

            def do_POST(self):
                content_length = int(self.headers["Content-Length"])
                body = self.rfile.read(content_length)
                unquoted_s = body.decode("utf-8")
                data = json.loads(unquoted_s)
                server._message_q.put(data)
                # Always return a 200 response to indicate it was gotten
                self.send_response(200)
                self.end_headers()

            def do_GET(self):

                raise NotImplementedError()

        class WebhookServer(HTTPServer):
            def __init__(
                self, server_address, RequestHandlerClass, bind_and_activate=True
            ):
                super().__init__(server_address, RequestHandlerClass, bind_and_activate)
                self._tunneled_url = None
                # Used to communicate to the main thread that a message has been recieved and needs to be processed.
                # The main thread is responsible for popping messages off as they are processed.
                self._message_q = queue.Queue()

            @property
            def url(self):
                return f"http://localhost:{self.server_port}"

            @property
            def tunneled_url(self):
                if not self._tunneled_url:
                    self._tunneled_url = tunnel(self.server_port)
                return self._tunneled_url

            def wait_for_message(
                self, message_predicate=lambda m: True, seconds_to_wait=5
            ):
                """ Block progress until a certain message is received that satisfies the passed message_predicate
                :param message_predicate: blocking function that takes the message and returns True
                    if it is the 'right one'.
                :param seconds_to_wait: seconds to wait for the message. This will throw a StopIteration
                    if the time runs out without a valid message.
                """
                start_time = time.time()
                poll_time = seconds_to_wait / 100
                while True:
                    try:
                        message = self._message_q.get(timeout=poll_time)
                        if message_predicate(message):
                            return
                        self._message_q.task_done()
                    except queue.Empty:
                        pass
                    if time.time() - start_time > seconds_to_wait:
                        raise TimeoutError()

        server = WebhookServer(("localhost", free_port), myHandler)
        servers.append(server)
        thread = Thread(target=server.serve_forever)
        thread.start()
        threads.append(thread)
        return server

    yield _webhook_server_factory
    for server, thread in zip(servers, threads):
        server.shutdown()
        thread.join()


def test_create_version_with_webhook(client, webhook_server_factory, new_document):
    server = webhook_server_factory()

    params = BTWebhookParams(
        events=["onshape.model.lifecycle.createversion",],
        url=server.tunneled_url,
        options=BTWebhookOptions(collapse_events=False),
        document_id=new_document.did,
    )
    client.webhooks_api.create_webhook(bt_webhook_params=params, _preload_content=False)
    server.wait_for_message(
        lambda m: m["event"] == "webhook.register", seconds_to_wait=30
    )

    new_document.make_version("new version!")

    server.wait_for_message(
        lambda m: m["event"] == "onshape.model.lifecycle.createversion",
        seconds_to_wait=30,
    )



# coding: utf-8

"""
    Onshape REST API

    The Onshape REST API consumed by all clients.  # noqa: E501

    The version of the OpenAPI document: 1.113
    Contact: api-support@onshape.zendesk.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import
import re  # noqa: F401
import sys  # noqa: F401

import six  # noqa: F401
import nulltype  # noqa: F401

from onshape_client.oas.model_utils import (  # noqa: F401
    ModelComposed,
    ModelNormal,
    ModelSimple,
    date,
    datetime,
    file_type,
    int,
    none_type,
    str,
    validate_get_composed_info,
)

try:
    from onshape_client.oas.models import bt_active_sheet_metal_filter2944
except ImportError:
    bt_active_sheet_metal_filter2944 = sys.modules[
        "onshape_client.oas.models.bt_active_sheet_metal_filter2944"
    ]
try:
    from onshape_client.oas.models import bt_allow_edge_point_filter2371
except ImportError:
    bt_allow_edge_point_filter2371 = sys.modules[
        "onshape_client.oas.models.bt_allow_edge_point_filter2371"
    ]
try:
    from onshape_client.oas.models import bt_allow_flattened_geometry_filter2140
except ImportError:
    bt_allow_flattened_geometry_filter2140 = sys.modules[
        "onshape_client.oas.models.bt_allow_flattened_geometry_filter2140"
    ]
try:
    from onshape_client.oas.models import bt_allow_mesh_geometry_filter1026
except ImportError:
    bt_allow_mesh_geometry_filter1026 = sys.modules[
        "onshape_client.oas.models.bt_allow_mesh_geometry_filter1026"
    ]
try:
    from onshape_client.oas.models import bt_and_filter110
except ImportError:
    bt_and_filter110 = sys.modules["onshape_client.oas.models.bt_and_filter110"]
try:
    from onshape_client.oas.models import bt_body_type_filter112
except ImportError:
    bt_body_type_filter112 = sys.modules[
        "onshape_client.oas.models.bt_body_type_filter112"
    ]
try:
    from onshape_client.oas.models import bt_closed_curve_filter1206
except ImportError:
    bt_closed_curve_filter1206 = sys.modules[
        "onshape_client.oas.models.bt_closed_curve_filter1206"
    ]
try:
    from onshape_client.oas.models import bt_construction_object_filter113
except ImportError:
    bt_construction_object_filter113 = sys.modules[
        "onshape_client.oas.models.bt_construction_object_filter113"
    ]
try:
    from onshape_client.oas.models import bt_edge_topology_filter122
except ImportError:
    bt_edge_topology_filter122 = sys.modules[
        "onshape_client.oas.models.bt_edge_topology_filter122"
    ]
try:
    from onshape_client.oas.models import bt_entity_type_filter124
except ImportError:
    bt_entity_type_filter124 = sys.modules[
        "onshape_client.oas.models.bt_entity_type_filter124"
    ]
try:
    from onshape_client.oas.models import bt_feature_filter127
except ImportError:
    bt_feature_filter127 = sys.modules["onshape_client.oas.models.bt_feature_filter127"]
try:
    from onshape_client.oas.models import bt_feature_type_filter962
except ImportError:
    bt_feature_type_filter962 = sys.modules[
        "onshape_client.oas.models.bt_feature_type_filter962"
    ]
try:
    from onshape_client.oas.models import bt_flat_sheet_metal_filter3018
except ImportError:
    bt_flat_sheet_metal_filter3018 = sys.modules[
        "onshape_client.oas.models.bt_flat_sheet_metal_filter3018"
    ]
try:
    from onshape_client.oas.models import bt_geometry_filter130
except ImportError:
    bt_geometry_filter130 = sys.modules[
        "onshape_client.oas.models.bt_geometry_filter130"
    ]
try:
    from onshape_client.oas.models import bt_image_filter853
except ImportError:
    bt_image_filter853 = sys.modules["onshape_client.oas.models.bt_image_filter853"]
try:
    from onshape_client.oas.models import bt_mate_connector_filter163
except ImportError:
    bt_mate_connector_filter163 = sys.modules[
        "onshape_client.oas.models.bt_mate_connector_filter163"
    ]
try:
    from onshape_client.oas.models import bt_mate_filter162
except ImportError:
    bt_mate_filter162 = sys.modules["onshape_client.oas.models.bt_mate_filter162"]
try:
    from onshape_client.oas.models import bt_modifiable_entity_only_filter1593
except ImportError:
    bt_modifiable_entity_only_filter1593 = sys.modules[
        "onshape_client.oas.models.bt_modifiable_entity_only_filter1593"
    ]
try:
    from onshape_client.oas.models import bt_not_filter165
except ImportError:
    bt_not_filter165 = sys.modules["onshape_client.oas.models.bt_not_filter165"]
try:
    from onshape_client.oas.models import bt_occurrence_filter166
except ImportError:
    bt_occurrence_filter166 = sys.modules[
        "onshape_client.oas.models.bt_occurrence_filter166"
    ]
try:
    from onshape_client.oas.models import bt_or_filter167
except ImportError:
    bt_or_filter167 = sys.modules["onshape_client.oas.models.bt_or_filter167"]
try:
    from onshape_client.oas.models import bt_plane_orientation_filter1700
except ImportError:
    bt_plane_orientation_filter1700 = sys.modules[
        "onshape_client.oas.models.bt_plane_orientation_filter1700"
    ]
try:
    from onshape_client.oas.models import bt_sketch_object_filter184
except ImportError:
    bt_sketch_object_filter184 = sys.modules[
        "onshape_client.oas.models.bt_sketch_object_filter184"
    ]
try:
    from onshape_client.oas.models import bt_text_object_filter1515
except ImportError:
    bt_text_object_filter1515 = sys.modules[
        "onshape_client.oas.models.bt_text_object_filter1515"
    ]
try:
    from onshape_client.oas.models import bt_text_stroke_filter461
except ImportError:
    bt_text_stroke_filter461 = sys.modules[
        "onshape_client.oas.models.bt_text_stroke_filter461"
    ]
try:
    from onshape_client.oas.models import btsm_definition_entity_type_filter1651
except ImportError:
    btsm_definition_entity_type_filter1651 = sys.modules[
        "onshape_client.oas.models.btsm_definition_entity_type_filter1651"
    ]


class BTQueryFilter183(ModelNormal):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.

    Attributes:
      allowed_values (dict): The key is the tuple path to the attribute
          and the for var_name this is (var_name,). The value is a dict
          with a capitalized key describing the allowed value and an allowed
          value. These dicts store the allowed enum values.
      attribute_map (dict): The key is attribute name
          and the value is json key in definition.
      discriminator_value_class_map (dict): A dict to go from the discriminator
          variable value to the discriminator class name.
      validations (dict): The key is the tuple path to the attribute
          and the for var_name this is (var_name,). The value is a dict
          that stores validations for max_length, min_length, max_items,
          min_items, exclusive_maximum, inclusive_maximum, exclusive_minimum,
          inclusive_minimum, and regex.
      additional_properties_type (tuple): A tuple of classes accepted
          as additional properties values.
    """

    allowed_values = {}

    validations = {}

    additional_properties_type = None

    @staticmethod
    def openapi_types():
        """
        This must be a class method so a model may have properties that are
        of type self, this ensures that we don't create a cyclic import

        Returns
            openapi_types (dict): The key is attribute name
                and the value is attribute type.
        """
        return {
            "bt_type": (str,),  # noqa: E501
        }

    @staticmethod
    def discriminator():
        return {
            "bt_type": {
                "BTTextStrokeFilter-461": bt_text_stroke_filter461.BTTextStrokeFilter461,
                "BTConstructionObjectFilter-113": bt_construction_object_filter113.BTConstructionObjectFilter113,
                "BTTextObjectFilter-1515": bt_text_object_filter1515.BTTextObjectFilter1515,
                "BTImageFilter-853": bt_image_filter853.BTImageFilter853,
                "BTAndFilter-110": bt_and_filter110.BTAndFilter110,
                "BTMateFilter-162": bt_mate_filter162.BTMateFilter162,
                "BTEdgeTopologyFilter-122": bt_edge_topology_filter122.BTEdgeTopologyFilter122,
                "BTSketchObjectFilter-184": bt_sketch_object_filter184.BTSketchObjectFilter184,
                "BTAllowMeshGeometryFilter-1026": bt_allow_mesh_geometry_filter1026.BTAllowMeshGeometryFilter1026,
                "BTOrFilter-167": bt_or_filter167.BTOrFilter167,
                "BTClosedCurveFilter-1206": bt_closed_curve_filter1206.BTClosedCurveFilter1206,
                "BTAllowFlattenedGeometryFilter-2140": bt_allow_flattened_geometry_filter2140.BTAllowFlattenedGeometryFilter2140,
                "BTGeometryFilter-130": bt_geometry_filter130.BTGeometryFilter130,
                "BTNotFilter-165": bt_not_filter165.BTNotFilter165,
                "BTPlaneOrientationFilter-1700": bt_plane_orientation_filter1700.BTPlaneOrientationFilter1700,
                "BTAllowEdgePointFilter-2371": bt_allow_edge_point_filter2371.BTAllowEdgePointFilter2371,
                "BTBodyTypeFilter-112": bt_body_type_filter112.BTBodyTypeFilter112,
                "BTFeatureFilter-127": bt_feature_filter127.BTFeatureFilter127,
                "BTSMDefinitionEntityTypeFilter-1651": btsm_definition_entity_type_filter1651.BTSMDefinitionEntityTypeFilter1651,
                "BTOccurrenceFilter-166": bt_occurrence_filter166.BTOccurrenceFilter166,
                "BTEntityTypeFilter-124": bt_entity_type_filter124.BTEntityTypeFilter124,
                "BTMateConnectorFilter-163": bt_mate_connector_filter163.BTMateConnectorFilter163,
                "BTFeatureTypeFilter-962": bt_feature_type_filter962.BTFeatureTypeFilter962,
                "BTFlatSheetMetalFilter-3018": bt_flat_sheet_metal_filter3018.BTFlatSheetMetalFilter3018,
                "BTActiveSheetMetalFilter-2944": bt_active_sheet_metal_filter2944.BTActiveSheetMetalFilter2944,
                "BTModifiableEntityOnlyFilter-1593": bt_modifiable_entity_only_filter1593.BTModifiableEntityOnlyFilter1593,
            },
        }

    attribute_map = {
        "bt_type": "btType",  # noqa: E501
    }

    @staticmethod
    def _composed_schemas():
        return None

    required_properties = set(
        [
            "_data_store",
            "_check_type",
            "_from_server",
            "_path_to_item",
            "_configuration",
        ]
    )

    def __init__(
        self,
        _check_type=True,
        _from_server=False,
        _path_to_item=(),
        _configuration=None,
        **kwargs
    ):  # noqa: E501
        """bt_query_filter183.BTQueryFilter183 - a model defined in OpenAPI

        Keyword Args:
            _check_type (bool): if True, values for parameters in openapi_types
                                will be type checked and a TypeError will be
                                raised if the wrong type is input.
                                Defaults to True
            _path_to_item (tuple/list): This is a list of keys or values to
                                drill down to the model in received_data
                                when deserializing a response
            _from_server (bool): True if the data is from the server
                                False if the data is from the client (default)
            _configuration (Configuration): the instance to use when
                                deserializing a file_type parameter.
                                If passed, type conversion is attempted
                                If omitted no type conversion is done.
            bt_type (str): [optional]  # noqa: E501
        """

        self._data_store = {}
        self._check_type = _check_type
        self._from_server = _from_server
        self._path_to_item = _path_to_item
        self._configuration = _configuration

        for var_name, var_value in six.iteritems(kwargs):
            if (
                var_name not in self.attribute_map
                and self._configuration is not None
                and self._configuration.discard_unknown_keys
                and self.additional_properties_type is None
            ):
                # discard variable.
                continue
            setattr(self, var_name, var_value)

    @classmethod
    def get_discriminator_class(cls, from_server, data):
        """Returns the child class specified by the discriminator"""
        discriminator = cls.discriminator()
        discr_propertyname_py = list(discriminator.keys())[0]
        discr_propertyname_js = cls.attribute_map[discr_propertyname_py]
        if from_server:
            class_name = data[discr_propertyname_js]
        else:
            class_name = data[discr_propertyname_py]
        class_name_to_discr_class = discriminator[discr_propertyname_py]
        return class_name_to_discr_class.get(class_name)



from onshape_client import Client, OnshapeElement
from onshape_client.oas import (
    BTWorkspacePartParams,
    BTPartAppearanceParams,
    BTColorParams,
    BTMaterialParams,
    BTMaterialPropertyParams,
)
import pytest


@pytest.mark.parametrize("element", ["ps_configurable_cube"], indirect=True)
def test_change_metadata(
    client: Client, new_copied_document_factory, element: OnshapeElement
):
    element = new_copied_document_factory(element).elements(
        filter_name="Configurable Cube"
    )[0]
    client.parts_api.update_part_metadata(
        **element._get_DWMVE(),
        partid="JHD",
        bt_workspace_part_params=BTWorkspacePartParams(
            appearance=BTPartAppearanceParams(
                color=BTColorParams(blue=0, red=255, green=0), opacity=32
            ),
            description="new description",
            part_number="new Part Number!",
            revision="r1",
            material=BTMaterialParams(
                displayName="ABS",
                id="ABS",
                properties=[
                    BTMaterialPropertyParams(
                        displayName="Density",
                        name="DENS",
                        type="REAL",
                        value="3000",
                        units="kg/m^3",
                        category="Physical",
                        description="Density",
                    )
                ],
            ),
        )
    )
    assert element.mass_properties.bodies["-all-"].mass[0] > 0.04



import six


# Alphabetical!
def get_http_server():
    if six.PY2:
        from BaseHTTPServer import HTTPServer
        from SimpleHTTPServer import SimpleHTTPRequestHandler as HTTPHandler
    else:
        from http.server import HTTPServer
        from http.server import BaseHTTPRequestHandler as HTTPHandler
    return HTTPServer, HTTPHandler


def get_parse():
    if six.PY2:
        from urlparse import urlparse as parse
    else:
        from urllib.parse import urlparse as parse
    return parse


def get_parse_qs():
    if six.PY2:
        from urlparse import urlparse as parse
    else:
        from urllib.parse import parse_qs as parse
    return parse


def get_sendable():
    if six.PY2:

        def sendable(s):
            return s

    else:

        def sendable(s):
            return bytes(s, "UTF-8")

    return sendable


def get_unquote():
    if six.PY2:
        from urllib import unquote as unquote
    else:
        from urllib.parse import unquote as unquote
    return unquote


# Alphabetical!
HTTPServer, HTTPHandler = get_http_server()
parse = get_parse()
sendable = get_sendable()
unquote = get_unquote()
parse_qs = get_parse_qs()



# coding: utf-8

"""
    Onshape REST API

    The Onshape REST API consumed by all clients.  # noqa: E501

    The version of the OpenAPI document: 1.111
    Contact: api-support@onshape.zendesk.com
    Generated by: https://openapi-generator.tech
"""

from __future__ import absolute_import

import sys  # noqa: F401

import six  # noqa: F401
from onshape_client.oas.model_utils import (  # noqa: F401
    ModelNormal,
    file_type,
    int,
    str,
)

try:
    from onshape_client.oas.models import form_data_body_part
except ImportError:
    form_data_body_part = sys.modules["onshape_client.oas.models.form_data_body_part"]
try:
    from onshape_client.oas.models import form_data_content_disposition
except ImportError:
    form_data_content_disposition = sys.modules[
        "onshape_client.oas.models.form_data_content_disposition"
    ]


class BTTranslationRequestBean(ModelNormal):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.

    Attributes:
      allowed_values (dict): The key is the tuple path to the attribute
          and the for var_name this is (var_name,). The value is a dict
          with a capitalized key describing the allowed value and an allowed
          value. These dicts store the allowed enum values.
      attribute_map (dict): The key is attribute name
          and the value is json key in definition.
      discriminator_value_class_map (dict): A dict to go from the discriminator
          variable value to the discriminator class name.
      validations (dict): The key is the tuple path to the attribute
          and the for var_name this is (var_name,). The value is a dict
          that stores validations for max_length, min_length, max_items,
          min_items, exclusive_maximum, inclusive_maximum, exclusive_minimum,
          inclusive_minimum, and regex.
      additional_properties_type (tuple): A tuple of classes accepted
          as additional properties values.
    """

    allowed_values = {
        ("owner_type",): {"USER": "USER", "COMPANY": "COMPANY", "ONSHAPE": "ONSHAPE",},
    }

    validations = {}

    additional_properties_type = None

    @staticmethod
    def openapi_types():
        """
        This must be a class method so a model may have properties that are
        of type self, this ensures that we don't create a cyclic import

        Returns
            openapi_types (dict): The key is attribute name
                and the value is attribute type.
        """
        return {
            "allow_faulty_parts": (bool,),  # noqa: E501
            "create_composite": (bool,),  # noqa: E501
            "create_drawing_if_possible": (bool,),  # noqa: E501
            "encoded_filename": (str,),  # noqa: E501
            "extract_assembly_hierarchy": (bool,),  # noqa: E501
            "file": (file_type,),  # noqa: E501
            "file_body_with_details": (
                form_data_body_part.FormDataBodyPart,
            ),  # noqa: E501
            "file_content_length": (int,),  # noqa: E501
            "file_detail": (
                form_data_content_disposition.FormDataContentDisposition,
            ),  # noqa: E501
            "flatten_assemblies": (bool,),  # noqa: E501
            "format_name": (str,),  # noqa: E501
            "isy_axis_is_up": (bool,),  # noqa: E501
            "join_adjacent_surfaces": (bool,),  # noqa: E501
            "location_element_id": (str,),  # noqa: E501
            "location_group_id": (str,),  # noqa: E501
            "location_position": (int,),  # noqa: E501
            "notify_user": (bool,),  # noqa: E501
            "owner_id": (str,),  # noqa: E501
            "owner_type": (str,),  # noqa: E501
            "parent_id": (str,),  # noqa: E501
            "project_id": (str,),  # noqa: E501
            "public": (bool,),  # noqa: E501
            "split_assemblies_into_multiple_documents": (bool,),  # noqa: E501
            "store_in_document": (bool,),  # noqa: E501
            "translate": (bool,),  # noqa: E501
            "unit": (str,),  # noqa: E501
            "upload_id": (str,),  # noqa: E501
            "version_string": (str,),  # noqa: E501
        }

    @staticmethod
    def discriminator():
        return None

    attribute_map = {
        "allow_faulty_parts": "allowFaultyParts",  # noqa: E501
        "create_composite": "createComposite",  # noqa: E501
        "create_drawing_if_possible": "createDrawingIfPossible",  # noqa: E501
        "encoded_filename": "encodedFilename",  # noqa: E501
        "extract_assembly_hierarchy": "extractAssemblyHierarchy",  # noqa: E501
        "file": "file",  # noqa: E501
        "file_body_with_details": "fileBodyWithDetails",  # noqa: E501
        "file_content_length": "fileContentLength",  # noqa: E501
        "file_detail": "fileDetail",  # noqa: E501
        "flatten_assemblies": "flattenAssemblies",  # noqa: E501
        "format_name": "formatName",  # noqa: E501
        "isy_axis_is_up": "isyAxisIsUp",  # noqa: E501
        "join_adjacent_surfaces": "joinAdjacentSurfaces",  # noqa: E501
        "location_element_id": "locationElementId",  # noqa: E501
        "location_group_id": "locationGroupId",  # noqa: E501
        "location_position": "locationPosition",  # noqa: E501
        "notify_user": "notifyUser",  # noqa: E501
        "owner_id": "ownerId",  # noqa: E501
        "owner_type": "ownerType",  # noqa: E501
        "parent_id": "parentId",  # noqa: E501
        "project_id": "projectId",  # noqa: E501
        "public": "public",  # noqa: E501
        "split_assemblies_into_multiple_documents": "splitAssembliesIntoMultipleDocuments",  # noqa: E501
        "store_in_document": "storeInDocument",  # noqa: E501
        "translate": "translate",  # noqa: E501
        "unit": "unit",  # noqa: E501
        "upload_id": "uploadId",  # noqa: E501
        "version_string": "versionString",  # noqa: E501
    }

    @staticmethod
    def _composed_schemas():
        return None

    required_properties = set(
        [
            "_data_store",
            "_check_type",
            "_from_server",
            "_path_to_item",
            "_configuration",
        ]
    )

    def __init__(
        self,
        _check_type=True,
        _from_server=False,
        _path_to_item=(),
        _configuration=None,
        **kwargs
    ):  # noqa: E501
        """bt_translation_request_bean.BTTranslationRequestBean - a model defined in OpenAPI


        Keyword Args:
            _check_type (bool): if True, values for parameters in openapi_types
                                will be type checked and a TypeError will be
                                raised if the wrong type is input.
                                Defaults to True
            _path_to_item (tuple/list): This is a list of keys or values to
                                drill down to the model in received_data
                                when deserializing a response
            _from_server (bool): True if the data is from the server
                                False if the data is from the client (default)
            _configuration (Configuration): the instance to use when
                                deserializing a file_type parameter.
                                If passed, type conversion is attempted
                                If omitted no type conversion is done.
            allow_faulty_parts (bool): [optional]  # noqa: E501
            create_composite (bool): [optional]  # noqa: E501
            create_drawing_if_possible (bool): [optional]  # noqa: E501
            encoded_filename (str): [optional]  # noqa: E501
            extract_assembly_hierarchy (bool): [optional]  # noqa: E501
            file (file_type): [optional]  # noqa: E501
            file_body_with_details (form_data_body_part.FormDataBodyPart): [optional]  # noqa: E501
            file_content_length (int): [optional]  # noqa: E501
            file_detail (form_data_content_disposition.FormDataContentDisposition): [optional]  # noqa: E501
            flatten_assemblies (bool): [optional]  # noqa: E501
            format_name (str): [optional]  # noqa: E501
            isy_axis_is_up (bool): [optional]  # noqa: E501
            join_adjacent_surfaces (bool): [optional]  # noqa: E501
            location_element_id (str): [optional]  # noqa: E501
            location_group_id (str): [optional]  # noqa: E501
            location_position (int): [optional]  # noqa: E501
            notify_user (bool): [optional]  # noqa: E501
            owner_id (str): [optional]  # noqa: E501
            owner_type (str): [optional]  # noqa: E501
            parent_id (str): [optional]  # noqa: E501
            project_id (str): [optional]  # noqa: E501
            public (bool): [optional]  # noqa: E501
            split_assemblies_into_multiple_documents (bool): [optional]  # noqa: E501
            store_in_document (bool): [optional]  # noqa: E501
            translate (bool): [optional]  # noqa: E501
            unit (str): [optional]  # noqa: E501
            upload_id (str): [optional]  # noqa: E501
            version_string (str): [optional]  # noqa: E501
        """

        self._data_store = {}
        self._check_type = _check_type
        self._from_server = _from_server
        self._path_to_item = _path_to_item
        self._configuration = _configuration

        for var_name, var_value in six.iteritems(kwargs):
            setattr(self, var_name, var_value)
